%%% A simple calculator for Church numerals in the simply typed
%%% lambda-calculus.
%%% Author: fp

module church.

%%% Church's representation of natural numbers 
%%% with zero, successor, plus, and times.

kind i type.    % The base type: a constant.
                % An integer has type (i -> i) -> i -> i.

%% The external predicates.

doc  ch
 "``ch G'' solves the result of applying G to Church's definition of
Zero, Succ, Plus, and Times, in that order.".

doc  chleq
 "``chleq G'' solves the result of applying G to Church's definition
of Zero, Succ, Plus, and Times and the eLP definition of Less-or-equal
on Church numbers.".

% The type declarations are left out, but could be copied from the
% output of the result of loading this module.

doc  church_defs
 "``church_defs Z S P T'' unifies Z with the Church's zero, S with
Church's successor, P with plus, and T with times.".

church_defs
 (f:i -> i \ x:i \ x)		 % zero.
 (n\ (f:i -> i) \ (x:i) \ (f (n f x)))		% succ
 (n\m\ (f:i -> i) \ (x:i) \ (n f (m f x):i):i)  % plus.
 (n\m\ (f:i -> i) \ (x:i) \ (n ((m f):(i -> i)) x):i)  % times. 
 .

ch G :- church_defs Z S P T, G Z S P T.

chleq G :- ch z\s\p\t\ (G z s p t (m\n\ (sigma C\ (p m C = n)))).
