;;; -*- Mode: Lisp; Package: SLTERMG -*-
(in-package "SLTERM")  ;; creates package for abstract syntax. 

(in-package "SLTERMG")  ;; enters package for generated code.  

(use-package '("ERGOLISP" "OPER" "OCC" "TERM" "SORT" "SB-RUNTIME" "LANG" "NEWATTR"))


(export '( SLTERM-PARSE ))

(DEFPARAMETER SLTERM-ABS-SYN-PACKAGE (FIND-PACKAGE "SLTERM")) 

(DEFUN SLTERM-PARSE (&KEY (NT 'SLTERM::SMODULE) ERROR-THRESHOLD ASK-ABOUT-BAD-TOKENS
  (RETURN-ERRORS NIL) (STREAM NIL STREAMP) STRING FILE (EXHAUST-STREAM NIL))
  (COND (STREAM)
        (STRING
         (SETF STREAM (MAKE-STRING-INPUT-STREAM STRING)))
        (FILE
         (SETF STREAM (OPEN FILE)))
        (T
         (ERROR
          "Must provide an input means -- either :stream, ~
			:string, or :file.")))
  (SETQ *SLTERM-KEYWORD-TABLE* (INIT-KEYWORD-TABLE SLTERM-KEYWORD-LIST))
  (LET ((*PARSER-ERROR* NIL)
        (*PARSER-ERROR-COUNT* 0)
        (*PARSER-RETURN-ERRORS* RETURN-ERRORS)
        (*PARSER-ABORT-THRESHOLD* ERROR-THRESHOLD)
        (*ASK-ABOUT-BAD-TOKENS* ASK-ABOUT-BAD-TOKENS)
        (*LEXICAL-STREAM* (OPEN-LEXICAL-STREAM (OPEN-PLACESTREAM STREAM)))
        (*HOLD-A1* NIL)
        (*HOLD-A2* NIL)
        (*HOLD-B1* NIL)
        (*HOLD-B2* NIL)
        (*ABS-SYN-PACKAGE* SLTERM-ABS-SYN-PACKAGE)
        (*READER-FUN* #'READER)
        (*APPLY-LEX-TERM-CONSTR-FUN* #'APPLY-LEXICAL-TERMINAL-CONSTRUCTOR)
        (*KEYWORD-TABLE* *SLTERM-KEYWORD-TABLE*)
        (*CLOSE-COMMENT-CHAR* SLTERM-CLOSE-COMMENT-CHAR)
        (*CASE-SENSITIVE* SLTERM-CASE-SENSITIVE))
    (INIT-LEXER *LEXICAL-STREAM*)
    (MULTIPLE-VALUE-BIND (ABS-SYNTAX ERROR-STRING ERROR-ARGS ERROR-PLACE) (UNWIND-PROTECT (CATCH
                      'PARSER-ABORT-CATCH
                      (PROG1
                        (CASE NT
                          (SLTERM::SMODULE (!SMODULE! 0))
                          (SLTERM::SIMPORT (!SIMPORT! 0))
                          (SLTERM::STRING-OR-ID (!STRING-OR-ID! 0))
                          (SLTERM::SMODENTRY (!SMODENTRY! 0))
                          (SLTERM::SLTERM-DOT (!SLTERM-DOT! 0))
                          (SLTERM:SLTERM (!SLTERM! 0))
                          (SLTERM:SLCOBJ (!SLCOBJ! 0))
                          (SLTERM:SLTYPE (!SLTYPE! 0))
                          (SLTERM:SLKIND (!SLKIND! 0))
                          (T (ERROR "Unknown nonterminal ~A." NT)))
                        (WHEN (OR FILE STRING EXHAUST-STREAM)
                          (CLET* (((TOKEN IGNORE PLACE) (PEEK-FIRST)))
                                 (UNLESS (OR (EQ TOKEN :EOF) (EQ TOKEN 'EOF))
                                   (DO-SYNTAX-ERROR
                                    "There is garbage at the end of your ~
			      file or string:~%~A"
                                    PLACE))))))
                     (UNLESS
                      STREAMP
                      (CLOSE STREAM)))
      (IF RETURN-ERRORS
          (VALUES ABS-SYNTAX *PARSER-ERROR* ERROR-PLACE ERROR-STRING ERROR-ARGS)
          (VALUES ABS-SYNTAX *PARSER-ERROR*))))) 


(DEFUN !SLKIND! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1
        V2)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2)
    (INITIALS-ONLY
     ((LA-MATCH ((SBST::|type| SBST::->)))
      (PROGN
        (LAM ((SBST::|type| EPSILON)) (GOBBLE-TOKEN))
        (LAM ((SBST::-> EPSILON)) (GOBBLE-TOKEN))
        (CODE-TO-SLOT V2 (!SLKIND! 0))
        (VALUE-TO-SLOT V0 1)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:KFUN (LIST V2)))))
     ((LA-MATCH ((SBST::|type| EPSILON)))
      (PROGN
        (LAM ((SBST::|type| EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 0)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:KTYPE (LIST)))))
     (T (INITIAL-ERROR '((SBST::|type| SBST::-> EPSILON)))))
    (VALUE-TO-SLOT V0 V1)
    V0)) 


(DEFUN !SLTYPE! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (LET (MTEMP
        V0
        V1
        V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
    (STACK-BRACKETS SBST::|(| SLTYPE)
    (INITIALS
     ((LA-MATCH ((SBST::|hacked\\ellided\\sltype|)))
      (PROGN
        (LAM ((SBST::|hacked\\ellided\\sltype| EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 3)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:ELLIDEDSLTYPE (LIST)))))
     ((LA-MATCH ((SBST::!ID!)))
      (PROGN
        (LAM ((SBST::!ID! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 0)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:TCON (LIST V1)))))
     (T
      (INITIAL-ERROR
       '((SBST::!ID! EPSILON) (SBST::|hacked\\ellided\\sltype| EPSILON)
        (SBST::|(| SBST::|(| SBST::|hacked\\ellided\\sltype| SBST::!ID!)))))
    (VALUE-TO-SLOT V0 V1)
    (EAT-BRACKETS (SBST::|)| SBST::|(|) SLTYPE)
    (COND ((>
            (COND ((MEMBER (PEEK-FIRST) '(SBST::->))
                   (SETQ MTEMP (PEEK-FIRST))
                   (CADR (ASSOC (PEEK-FIRST) '((SBST::JUX 20) (SBST::-> 11)))))
                  ((MEMBER (PEEK-FIRST)
                           '(SBST::|(| SBST::|hacked\\ellided\\sltype|
                            SBST::!ID!))
                   (SETQ MTEMP '|keyword-sentinel5662|)
                   20)
                  (T
                   0))
            RBP)
           (LOOP (CLEAN-VARIABLES (V1 V2 V3))
                 (CASE MTEMP
                   (|keyword-sentinel5662|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (CODE-TO-SLOT V3 (!SLTYPE! 21))
                      (VALUE-TO-SLOT V0 2)
                      (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:TAPPL (LIST V2 V3)))))
                   (SBST::->
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::-> EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTYPE! 10))
                      (VALUE-TO-SLOT V0 1)
                      (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:TFUN (LIST V2 V3)))))
                   (T
                    (MEDIAL-ERROR
                     '(SBST::-> SBST::|(| SBST::|hacked\\ellided\\sltype|
                      SBST::!ID!))))
                 (VALUE-TO-SLOT V0 V1)
                 (EAT-BRACKETS (SBST::|)| SBST::|(|) SLTYPE)
                 (WHEN (<=
                   (COND ((MEMBER (PEEK-FIRST) '(SBST::->))
                          (SETQ MTEMP (PEEK-FIRST))
                          (CADR
                           (ASSOC (PEEK-FIRST) '((SBST::JUX 20) (SBST::-> 11)))))
                         ((MEMBER (PEEK-FIRST)
                                  '(SBST::|(| SBST::|hacked\\ellided\\sltype|
                                   SBST::!ID!))
                          (SETQ MTEMP '|keyword-sentinel5662|)
                          20)
                         (T
                          0))
                   RBP)
                   (RETURN NIL)))))
    V0)) 


(DEFUN !SLCOBJ! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1)
    (ERGO-IGNORE-IF-UNUSED V0 V1)
    (INITIALS-ONLY
     ((LA-MATCH ((SBST::!KEYWORD!)))
      (PROGN
        (LAM ((SBST::!KEYWORD! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 0)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::CKEYWORD (LIST V1)))))
     ((LA-MATCH ((SBST::!ID!)))
      (PROGN
        (LAM ((SBST::!ID! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 1)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:CNAMED (LIST V1)))))
     ((LA-MATCH ((SBST::!NUMBER!)))
      (PROGN
        (LAM ((SBST::!NUMBER! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 2)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:CNUMBER (LIST V1)))))
     ((LA-MATCH ((SBST::!STRING!)))
      (PROGN
        (LAM ((SBST::!STRING! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 3)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:CSTRING (LIST V1)))))
     (T
      (INITIAL-ERROR
       '((SBST::!STRING! EPSILON) (SBST::!NUMBER! EPSILON) (SBST::!ID! EPSILON)
        (SBST::!KEYWORD! EPSILON)))))
    (VALUE-TO-SLOT V0 V1)
    V0)) 


(DEFUN !SLTERM! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (LET (MTEMP
        V0
        V1
        V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
    (STACK-BRACKETS SBST::|(| SLTERM)
    (INITIALS
     ((LA-MATCH
       ((SBST::!KEYWORD!) (SBST::!ID!) (SBST::!NUMBER!) (SBST::!STRING!)))
      (PROGN
        (CODE-TO-SLOT V1 (!SLCOBJ! 0))
        (VALUE-TO-SLOT V0 36)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:CON (LIST V1)))))
     ((LA-MATCH ((SBST::|hacked\\ellided\\slterm|)))
      (PROGN
        (LAM ((SBST::|hacked\\ellided\\slterm| EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 35)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:ELLIDEDSLTERM (LIST)))))
     (T
      (INITIAL-ERROR
       '((SBST::|hacked\\ellided\\slterm| EPSILON) (SBST::!KEYWORD! EPSILON)
        (SBST::!ID! EPSILON) (SBST::!NUMBER! EPSILON) (SBST::!STRING! EPSILON)
        (SBST::|(| SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID!
         SBST::!KEYWORD! SBST::|hacked\\ellided\\slterm|)))))
    (VALUE-TO-SLOT V0 V1)
    (EAT-BRACKETS (SBST::|)| SBST::|(|) SLTERM)
    (COND ((>
            (COND ((MEMBER (PEEK-FIRST)
                           '(SBST::|,| SBST::|;| SBST::=> SBST::|:-|
                            SBST::|hacked\\reverse\\implies| SBST::==> SBST::=
                            SBST::|is| SBST::|and| SBST::|or| SBST::|imp|
                            SBST::|equiv| SBST::|#| SBST::|#e| SBST::|#p|
                            SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2
                            SBST::&& SBST::|vv| SBST::==>> SBST::|=:=|
                            SBST::|=\\=| SBST::< SBST::> SBST::=< SBST::>=
                            SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
                            SBST::|mod| SBST::|\\| SBST::|:|))
                   (SETQ MTEMP (PEEK-FIRST))
                   (CADR
                    (ASSOC (PEEK-FIRST)
                           '((SBST::|:| 200) (SBST::|\\| 191) (SBST::JUX 180)
                            (SBST::|mod| 170) (SBST::|div| 170) (SBST::* 170)
                            (SBST::- 160) (SBST::+ 160) (SBST::|::| 151)
                            (SBST::>= 140) (SBST::=< 140) (SBST::> 140)
                            (SBST::< 140) (SBST::|=\\=| 130) (SBST::|=:=| 130)
                            (SBST::|or| 121) (SBST::|and| 121)
                            (SBST::|equiv| 111) (SBST::|imp| 111)
                            (SBST::|#t| 100) (SBST::|#p| 100) (SBST::|#e| 90)
                            (SBST::|#| 90) (SBST::--> 81) (SBST::>-2 70)
                            (SBST::>-1 70) (SBST::>- 70) (SBST::|vv| 61)
                            (SBST::&& 61) (SBST::==>> 51) (SBST::|is| 50)
                            (SBST::= 50) (SBST::==> 41) (SBST::=> 41)
                            (SBST::|,| 31) (SBST::|;| 21)
                            (SBST::|hacked\\reverse\\implies| 10)
                            (SBST::|:-| 10)))))
                  ((MEMBER (PEEK-FIRST)
                           '(SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID!
                            SBST::!KEYWORD! SBST::|hacked\\ellided\\slterm|))
                   (SETQ MTEMP '|keyword-sentinel5643|)
                   180)
                  (T
                   0))
            RBP)
           (LOOP (CLEAN-VARIABLES (V1 V2 V3))
                 (CASE MTEMP
                   (SBST::|:|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|:| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTYPE! 0))
                      (VALUE-TO-SLOT V0 39)
                      (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:TYPED (LIST V2 V3)))))
                   (SBST::|\\|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|\\| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 190))
                      (VALUE-TO-SLOT V0 38)
                      (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:ABST (LIST V2 V3)))))
                   (|keyword-sentinel5643|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (CODE-TO-SLOT V3 (!SLTERM! 181))
                      (VALUE-TO-SLOT V0 37)
                      (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM:APPL (LIST V2 V3)))))
                   (SBST::|mod|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|mod| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 171))
                      (VALUE-TO-SLOT V0 34)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "mod")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|div|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|div| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 171))
                      (VALUE-TO-SLOT V0 33)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "div")))))
                                                                V2))
                                                 V3)))))
                   (SBST::*
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::* EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 171))
                      (VALUE-TO-SLOT V0 32)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "*")))))
                                                                V2))
                                                 V3)))))
                   (SBST::-
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::- EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 161))
                      (VALUE-TO-SLOT V0 31)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "-")))))
                                                                V2))
                                                 V3)))))
                   (SBST::+
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::+ EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 161))
                      (VALUE-TO-SLOT V0 30)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "+")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|::|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|::| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 150))
                      (VALUE-TO-SLOT V0 29)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "::")))))
                                                                V2))
                                                 V3)))))
                   (SBST::>=
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::>= EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 141))
                      (VALUE-TO-SLOT V0 28)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ">=")))))
                                                                V2))
                                                 V3)))))
                   (SBST::=<
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::=< EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 141))
                      (VALUE-TO-SLOT V0 27)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "=<")))))
                                                                V2))
                                                 V3)))))
                   (SBST::>
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::> EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 141))
                      (VALUE-TO-SLOT V0 26)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ">")))))
                                                                V2))
                                                 V3)))))
                   (SBST::<
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::< EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 141))
                      (VALUE-TO-SLOT V0 25)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "<")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|=\\=|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|=\\=| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 131))
                      (VALUE-TO-SLOT V0 24)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "=\\=")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|=:=|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|=:=| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 131))
                      (VALUE-TO-SLOT V0 23)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "=:=")))))
                                                                V2))
                                                 V3)))))
                   (SBST::==>>
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::==>> EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 50))
                      (VALUE-TO-SLOT V0 22)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "==>>")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|vv|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|vv| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 60))
                      (VALUE-TO-SLOT V0 21)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "vv")))))
                                                                V2))
                                                 V3)))))
                   (SBST::&&
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::&& EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 60))
                      (VALUE-TO-SLOT V0 20)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "&&")))))
                                                                V2))
                                                 V3)))))
                   (SBST::>-2
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::>-2 EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 71))
                      (VALUE-TO-SLOT V0 19)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ">-2")))))
                                                                V2))
                                                 V3)))))
                   (SBST::>-1
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::>-1 EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 71))
                      (VALUE-TO-SLOT V0 18)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ">-1")))))
                                                                V2))
                                                 V3)))))
                   (SBST::>-
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::>- EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 71))
                      (VALUE-TO-SLOT V0 17)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ">-")))))
                                                                V2))
                                                 V3)))))
                   (SBST::-->
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::--> EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 80))
                      (VALUE-TO-SLOT V0 16)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "-->")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|#t|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|#t| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 101))
                      (VALUE-TO-SLOT V0 15)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "#t")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|#p|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|#p| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 101))
                      (VALUE-TO-SLOT V0 14)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "#p")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|#e|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|#e| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 91))
                      (VALUE-TO-SLOT V0 13)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "#e")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|#|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|#| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 91))
                      (VALUE-TO-SLOT V0 12)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "#")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|equiv|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|equiv| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 110))
                      (VALUE-TO-SLOT V0 11)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "equiv")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|imp|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|imp| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 110))
                      (VALUE-TO-SLOT V0 10)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "imp")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|or|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|or| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 120))
                      (VALUE-TO-SLOT V0 9)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "or")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|and|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|and| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 120))
                      (VALUE-TO-SLOT V0 8)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "and")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|is|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|is| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 51))
                      (VALUE-TO-SLOT V0 7)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "is")))))
                                                                V2))
                                                 V3)))))
                   (SBST::=
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::= EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 51))
                      (VALUE-TO-SLOT V0 6)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "=")))))
                                                                V2))
                                                 V3)))))
                   (SBST::==>
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::==> EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 40))
                      (VALUE-TO-SLOT V0 5)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "==>")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|hacked\\reverse\\implies|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|hacked\\reverse\\implies| EPSILON))
                           (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 11))
                      (VALUE-TO-SLOT V0 4)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ":-")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|:-|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|:-| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 11))
                      (VALUE-TO-SLOT V0 3)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "=>")))))
                                                                V3))
                                                 V2)))))
                   (SBST::=>
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::=> EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 40))
                      (VALUE-TO-SLOT V0 2)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     "=>")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|;|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|;| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 20))
                      (VALUE-TO-SLOT V0 1)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ";")))))
                                                                V2))
                                                 V3)))))
                   (SBST::|,|
                    (PROGN
                      (SLOT-TO-SLOT V2 V0)
                      (LAM ((SBST::|,| EPSILON)) (GOBBLE-TOKEN))
                      (CODE-TO-SLOT V3 (!SLTERM! 30))
                      (VALUE-TO-SLOT V0 0)
                      (AS-TO-SLOT V1
                                  (MAKE-SB-TERM 'SLTERM:APPL
                                                (LIST
                                                 (MAKE-SB-TERM 'SLTERM:APPL
                                                               (LIST
                                                                (MAKE-SB-TERM
                                                                 'SLTERM:CON
                                                                 (LIST
                                                                  (MAKE-SB-TERM
                                                                   'SLTERM::CKEYWORD
                                                                   (LIST
                                                                    (MK-STRING
                                                                     ",")))))
                                                                V2))
                                                 V3)))))
                   (T
                    (MEDIAL-ERROR
                     '(SBST::|,| SBST::|;| SBST::=> SBST::|:-|
                      SBST::|hacked\\reverse\\implies| SBST::==> SBST::=
                      SBST::|is| SBST::|and| SBST::|or| SBST::|imp|
                      SBST::|equiv| SBST::|#| SBST::|#e| SBST::|#p| SBST::|#t|
                      SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
                      SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::<
                      SBST::> SBST::=< SBST::>= SBST::|::| SBST::+ SBST::-
                      SBST::* SBST::|div| SBST::|mod| SBST::|(| SBST::!STRING!
                      SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
                      SBST::|hacked\\ellided\\slterm| SBST::|\\| SBST::|:|))))
                 (VALUE-TO-SLOT V0 V1)
                 (EAT-BRACKETS (SBST::|)| SBST::|(|) SLTERM)
                 (WHEN (<=
                   (COND ((MEMBER (PEEK-FIRST)
                                  '(SBST::|,| SBST::|;| SBST::=> SBST::|:-|
                                   SBST::|hacked\\reverse\\implies| SBST::==>
                                   SBST::= SBST::|is| SBST::|and| SBST::|or|
                                   SBST::|imp| SBST::|equiv| SBST::|#|
                                   SBST::|#e| SBST::|#p| SBST::|#t| SBST::-->
                                   SBST::>- SBST::>-1 SBST::>-2 SBST::&&
                                   SBST::|vv| SBST::==>> SBST::|=:=|
                                   SBST::|=\\=| SBST::< SBST::> SBST::=<
                                   SBST::>= SBST::|::| SBST::+ SBST::- SBST::*
                                   SBST::|div| SBST::|mod| SBST::|\\| SBST::|:|))
                          (SETQ MTEMP (PEEK-FIRST))
                          (CADR
                           (ASSOC (PEEK-FIRST)
                                  '((SBST::|:| 200) (SBST::|\\| 191)
                                   (SBST::JUX 180) (SBST::|mod| 170)
                                   (SBST::|div| 170) (SBST::* 170)
                                   (SBST::- 160) (SBST::+ 160) (SBST::|::| 151)
                                   (SBST::>= 140) (SBST::=< 140) (SBST::> 140)
                                   (SBST::< 140) (SBST::|=\\=| 130)
                                   (SBST::|=:=| 130) (SBST::|or| 121)
                                   (SBST::|and| 121) (SBST::|equiv| 111)
                                   (SBST::|imp| 111) (SBST::|#t| 100)
                                   (SBST::|#p| 100) (SBST::|#e| 90)
                                   (SBST::|#| 90) (SBST::--> 81) (SBST::>-2 70)
                                   (SBST::>-1 70) (SBST::>- 70) (SBST::|vv| 61)
                                   (SBST::&& 61) (SBST::==>> 51)
                                   (SBST::|is| 50) (SBST::= 50) (SBST::==> 41)
                                   (SBST::=> 41) (SBST::|,| 31) (SBST::|;| 21)
                                   (SBST::|hacked\\reverse\\implies| 10)
                                   (SBST::|:-| 10)))))
                         ((MEMBER (PEEK-FIRST)
                                  '(SBST::|(| SBST::!STRING! SBST::!NUMBER!
                                   SBST::!ID! SBST::!KEYWORD!
                                   SBST::|hacked\\ellided\\slterm|))
                          (SETQ MTEMP '|keyword-sentinel5643|)
                          180)
                         (T
                          0))
                   RBP)
                   (RETURN NIL)))))
    V0)) 


(DEFUN !SLTERM-DOT! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1
        V2)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2)
    (INITIALS-ONLY
     ((LA-MATCH
       ((SBST::|(|) (SBST::!STRING!) (SBST::!NUMBER!) (SBST::!ID!)
        (SBST::!KEYWORD!) (SBST::|hacked\\ellided\\slterm|)))
      (PROGN
        (CODE-TO-SLOT V2 (!SLTERM! 0))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 0)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::SLTERM-DOT (LIST V2)))))
     ((LA-MATCH ((SBST::\.)))
      (PROGN
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 1)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::END-OF-INPUT (LIST)))))
     (T
      (INITIAL-ERROR
       '((SBST::\. EPSILON)
        (SBST::|hacked\\ellided\\slterm| SBST::|,| SBST::|;| SBST::=>
         SBST::|:-| SBST::|hacked\\reverse\\implies| SBST::==> SBST::=
         SBST::|is| SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#|
         SBST::|#e| SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1
         SBST::>-2 SBST::&& SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=|
         SBST::< SBST::> SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::*
         SBST::|div| SBST::|mod| SBST::|\\| SBST::|:|
         SBST::|hacked\\ellided\\slterm| SBST::|(| SBST::!STRING!
         SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD! SBST::\.)
        (SBST::!KEYWORD! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::!ID! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::!NUMBER! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::!STRING! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|(| SBST::!STRING!
         SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!)))))
    (VALUE-TO-SLOT V0 V1)
    V0)) 


(DEFUN !SMODENTRY! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1
        V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
    (INITIALS-ONLY
     ((LA-MATCH ((SBST::|kind|)))
      (PROGN
        (LAM ((SBST::|kind| EPSILON)) (GOBBLE-TOKEN))
        (LAM ((SBST::!ID! EPSILON)) (GOBBLE-TO-SLOT V2))
        (CODE-TO-SLOT V3 (!SLKIND! 0))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 0)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::MKINDING (LIST V2 V3)))))
     ((LA-MATCH ((SBST::|type| SBST::!ID!)))
      (PROGN
        (LAM ((SBST::|type| EPSILON)) (GOBBLE-TOKEN))
        (LAM ((SBST::!ID! EPSILON)) (GOBBLE-TO-SLOT V2))
        (CODE-TO-SLOT V3 (!SLTYPE! 0))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 1)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::MTYPING (LIST V2 V3)))))
     ((LA-MATCH ((SBST::|type| SBST::!KEYWORD!)))
      (PROGN
        (LAM ((SBST::|type| EPSILON)) (GOBBLE-TOKEN))
        (LAM ((SBST::!KEYWORD! EPSILON)) (GOBBLE-TO-SLOT V2))
        (CODE-TO-SLOT V3 (!SLTYPE! 0))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 2)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::MKEYTYPING (LIST V2 V3)))))
     ((LA-MATCH ((SBST::|index| SBST::!ID!)))
      (PROGN
        (LAM ((SBST::|index| EPSILON)) (GOBBLE-TOKEN))
        (LAM ((SBST::!ID! EPSILON)) (GOBBLE-TO-SLOT V2))
        (LAM ((SBST::!NUMBER! EPSILON)) (GOBBLE-TO-SLOT V3))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 3)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::MINDEXING (LIST V2 V3)))))
     ((LA-MATCH ((SBST::|index| SBST::!KEYWORD!)))
      (PROGN
        (LAM ((SBST::|index| EPSILON)) (GOBBLE-TOKEN))
        (LAM ((SBST::!KEYWORD! EPSILON)) (GOBBLE-TO-SLOT V2))
        (LAM ((SBST::!NUMBER! EPSILON)) (GOBBLE-TO-SLOT V3))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 4)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::MKEYINDEXING (LIST V2 V3)))))
     ((LA-MATCH
       ((SBST::|(|) (SBST::!STRING!) (SBST::!NUMBER!) (SBST::!ID!)
        (SBST::!KEYWORD!) (SBST::|hacked\\ellided\\slterm|)))
      (PROGN
        (CODE-TO-SLOT V2 (!SLTERM! 0))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (VALUE-TO-SLOT V0 5)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::MSDFORM (LIST V2)))))
     (T
      (INITIAL-ERROR
       '((SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|(| SBST::!STRING!
          SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!)
        (SBST::!STRING! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::!NUMBER! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::!ID! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::!KEYWORD! SBST::|,| SBST::|;| SBST::=> SBST::|:-|
         SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
         SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#| SBST::|#e|
         SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1 SBST::>-2 SBST::&&
         SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=| SBST::< SBST::>
         SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::* SBST::|div|
         SBST::|mod| SBST::|\\| SBST::|:| SBST::|hacked\\ellided\\slterm|
         SBST::|(| SBST::!STRING! SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!
         SBST::\.)
        (SBST::|hacked\\ellided\\slterm| SBST::|,| SBST::|;| SBST::=>
         SBST::|:-| SBST::|hacked\\reverse\\implies| SBST::==> SBST::=
         SBST::|is| SBST::|and| SBST::|or| SBST::|imp| SBST::|equiv| SBST::|#|
         SBST::|#e| SBST::|#p| SBST::|#t| SBST::--> SBST::>- SBST::>-1
         SBST::>-2 SBST::&& SBST::|vv| SBST::==>> SBST::|=:=| SBST::|=\\=|
         SBST::< SBST::> SBST::=< SBST::>= SBST::|::| SBST::+ SBST::- SBST::*
         SBST::|div| SBST::|mod| SBST::|\\| SBST::|:|
         SBST::|hacked\\ellided\\slterm| SBST::|(| SBST::!STRING!
         SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD! SBST::\.)
        (SBST::|index| SBST::!KEYWORD! SBST::!ID!)
        (SBST::|type| SBST::!KEYWORD! SBST::!ID!) (SBST::|kind| SBST::!ID!)))))
    (VALUE-TO-SLOT V0 V1)
    V0)) 


(DEFUN !STRING-OR-ID! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1)
    (ERGO-IGNORE-IF-UNUSED V0 V1)
    (INITIALS-ONLY
     ((LA-MATCH ((SBST::!STRING!)))
      (PROGN
        (LAM ((SBST::!STRING! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 0)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::ISSTRING (LIST V1)))))
     ((LA-MATCH ((SBST::!ID!)))
      (PROGN
        (LAM ((SBST::!ID! EPSILON)) (GOBBLE-TO-SLOT V1))
        (VALUE-TO-SLOT V0 1)
        (AS-TO-SLOT V1 (MAKE-SB-TERM 'SLTERM::ISID (LIST V1)))))
     (T (INITIAL-ERROR '((SBST::!ID! EPSILON) (SBST::!STRING! EPSILON)))))
    (VALUE-TO-SLOT V0 V1)
    V0)) 


(DEFUN !SIMPORT! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1
        V2)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2)
    (INITIALS-ONLY
     ((LA-MATCH ((SBST::|import|)))
      (PROGN
        (LAM ((SBST::|import| EPSILON)) (GOBBLE-TOKEN))
        (STAR-PARSE ((SBST::!ID! EPSILON) (SBST::!STRING! EPSILON))
                    (PROGN
                      (CODE-TO-SLOT V2 (!STRING-OR-ID! 0))
                      NIL) V1 V2)
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (AS-TO-SLOT V0
                    (MAKE-SB-TERM 'SLTERM::SIMPORT
                                  (LIST
                                   (MAKE-SB-TERM 'SLTERM::IMPORT-LIST
                                                 (DS-TEMP-REPT (CK-REPT-REF V1))))))))
     (T (INITIAL-ERROR '((SBST::|import| SBST::\. SBST::!ID! SBST::!STRING!)))))
    NIL
    V0)) 


(DEFUN !SMODULE! (RBP &OPTIONAL (BRACKET-LIST (EMPTY-BRACKET-LIST)))
  (DECLARE (IGNORE RBP))
  (DECLARE (IGNORE BRACKET-LIST))
  (LET (V0
        V1
        V2
        V3
        V4
        V5)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5)
    (INITIALS-ONLY
     ((LA-MATCH ((SBST::|module|)))
      (PROGN
        (LAM ((SBST::|module| EPSILON)) (GOBBLE-TOKEN))
        (CODE-TO-SLOT V1 (!STRING-OR-ID! 0))
        (LAM ((SBST::\. EPSILON)) (GOBBLE-TOKEN))
        (STAR-PARSE ((SBST::|import| SBST::\. SBST::!ID! SBST::!STRING!))
                    (CODE-TO-SLOT V3 (!SIMPORT! 0)) V2 V3)
        (STAR-PARSE
         ((SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|(| SBST::!STRING!
           SBST::!NUMBER! SBST::!ID! SBST::!KEYWORD!)
          (SBST::!STRING! SBST::!KEYWORD! SBST::!ID! SBST::!NUMBER!
           SBST::!STRING! SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|:|
           SBST::|\\| SBST::|mod| SBST::|div| SBST::* SBST::- SBST::+
           SBST::|::| SBST::>= SBST::=< SBST::> SBST::< SBST::|=\\=|
           SBST::|=:=| SBST::==>> SBST::|vv| SBST::&& SBST::>-2 SBST::>-1
           SBST::>- SBST::--> SBST::|#t| SBST::|#p| SBST::|#e| SBST::|#|
           SBST::|equiv| SBST::|imp| SBST::|or| SBST::|and| SBST::|is| SBST::=
           SBST::==> SBST::|hacked\\reverse\\implies| SBST::|:-| SBST::=>
           SBST::|;| SBST::|,| SBST::\.)
          (SBST::!NUMBER! SBST::!KEYWORD! SBST::!ID! SBST::!NUMBER!
           SBST::!STRING! SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|:|
           SBST::|\\| SBST::|mod| SBST::|div| SBST::* SBST::- SBST::+
           SBST::|::| SBST::>= SBST::=< SBST::> SBST::< SBST::|=\\=|
           SBST::|=:=| SBST::==>> SBST::|vv| SBST::&& SBST::>-2 SBST::>-1
           SBST::>- SBST::--> SBST::|#t| SBST::|#p| SBST::|#e| SBST::|#|
           SBST::|equiv| SBST::|imp| SBST::|or| SBST::|and| SBST::|is| SBST::=
           SBST::==> SBST::|hacked\\reverse\\implies| SBST::|:-| SBST::=>
           SBST::|;| SBST::|,| SBST::\.)
          (SBST::!ID! SBST::!KEYWORD! SBST::!ID! SBST::!NUMBER! SBST::!STRING!
           SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|:| SBST::|\\|
           SBST::|mod| SBST::|div| SBST::* SBST::- SBST::+ SBST::|::| SBST::>=
           SBST::=< SBST::> SBST::< SBST::|=\\=| SBST::|=:=| SBST::==>>
           SBST::|vv| SBST::&& SBST::>-2 SBST::>-1 SBST::>- SBST::-->
           SBST::|#t| SBST::|#p| SBST::|#e| SBST::|#| SBST::|equiv| SBST::|imp|
           SBST::|or| SBST::|and| SBST::|is| SBST::= SBST::==>
           SBST::|hacked\\reverse\\implies| SBST::|:-| SBST::=> SBST::|;|
           SBST::|,| SBST::\.)
          (SBST::!KEYWORD! SBST::!KEYWORD! SBST::!ID! SBST::!NUMBER!
           SBST::!STRING! SBST::|(| SBST::|hacked\\ellided\\slterm| SBST::|:|
           SBST::|\\| SBST::|mod| SBST::|div| SBST::* SBST::- SBST::+
           SBST::|::| SBST::>= SBST::=< SBST::> SBST::< SBST::|=\\=|
           SBST::|=:=| SBST::==>> SBST::|vv| SBST::&& SBST::>-2 SBST::>-1
           SBST::>- SBST::--> SBST::|#t| SBST::|#p| SBST::|#e| SBST::|#|
           SBST::|equiv| SBST::|imp| SBST::|or| SBST::|and| SBST::|is| SBST::=
           SBST::==> SBST::|hacked\\reverse\\implies| SBST::|:-| SBST::=>
           SBST::|;| SBST::|,| SBST::\.)
          (SBST::|hacked\\ellided\\slterm| SBST::!KEYWORD! SBST::!ID!
           SBST::!NUMBER! SBST::!STRING! SBST::|(|
           SBST::|hacked\\ellided\\slterm| SBST::|:| SBST::|\\| SBST::|mod|
           SBST::|div| SBST::* SBST::- SBST::+ SBST::|::| SBST::>= SBST::=<
           SBST::> SBST::< SBST::|=\\=| SBST::|=:=| SBST::==>> SBST::|vv|
           SBST::&& SBST::>-2 SBST::>-1 SBST::>- SBST::--> SBST::|#t|
           SBST::|#p| SBST::|#e| SBST::|#| SBST::|equiv| SBST::|imp| SBST::|or|
           SBST::|and| SBST::|is| SBST::= SBST::==>
           SBST::|hacked\\reverse\\implies| SBST::|:-| SBST::=> SBST::|;|
           SBST::|,| SBST::\.)
          (SBST::|index| SBST::!KEYWORD! SBST::!ID!)
          (SBST::|type| SBST::!KEYWORD! SBST::!ID!) (SBST::|kind| SBST::!ID!))
         (CODE-TO-SLOT V5 (!SMODENTRY! 0)) V4 V5)
        (AS-TO-SLOT V0
                    (MAKE-SB-TERM 'SLTERM::SMODULE
                                  (LIST V1
                                        (MAKE-SB-TERM 'SLTERM::IMPORTS
                                                      (DS-TEMP-REPT
                                                       (CK-REPT-REF V2)))
                                        (MAKE-SB-TERM 'SLTERM::MODENTRIES
                                                      (DS-TEMP-REPT
                                                       (CK-REPT-REF V4))))))))
     (T (INITIAL-ERROR '((SBST::|module| SBST::!STRING! SBST::!ID!)))))
    NIL
    V0)) 

