module inter_tacs.

%  Some tacticals and tactics which define an interactive
%  tactical theorem prover.

import tacticals maptac.

type    orelse!         (goal -> goal -> o)
                          -> (goal -> goal -> o) -> goal -> goal -> o.
type    with_tacs       string -> (goal -> goal -> o) -> goal -> goal -> o.
type    inter_repeat    (goal -> goal -> o) -> goal -> goal -> o.
type    query           (goal -> (goal -> goal -> o) -> o) ->
                         goal -> goal -> o.
type    backup          goal -> goal -> o.
type    inter           (goal -> (goal -> goal -> o) -> o) ->
                         goal -> goal -> o.
type    report_fail     goal -> goal -> o.
type    quit            goal -> goal -> o.
type    do              o -> goal -> goal -> o.
type    basic_io        (goal -> o) -> ((goal -> goal -> o) -> o) ->
                         goal -> (goal -> goal -> o) -> o.
type    readtac         (goal -> goal -> o) -> o.

% The orelse! tactical is like orelse, but eliminates backtracking points.

orelse! Tac1 Tac2 InGoal OutGoal :- Tac1 InGoal OutGoal,!; Tac2 InGoal OutGoal.

% The with_tacs tactical provides a way to dynamically import modules.

with_tacs M Tac InGoal OutGoal :- M ==> (Tac InGoal OutGoal).

%  The inter_repeat tactical allows the user to stop the proof by
%  invoking the quit tactic (resulting in MidGoal = ff).

inter_repeat Tac InGoal OutGoal :-
   Tac InGoal MidGoal,
   ((MidGoal = ff), !, (OutGoal = InGoal);
   maptac (inter_repeat Tac) MidGoal OutGoal).

% The query tactic asks the user for a tactic to apply. It allows the user
% to back up one step at a time.

query IO InGoal OutGoal :-
   IO InGoal Tac,
   ((Tac = backup), !, fail;
    orelse! Tac report_fail InGoal OutGoal;
    query IO InGoal OutGoal).

inter IO InGoal OutGoal :- inter_repeat (query IO) InGoal OutGoal.

report_fail Goal Goal :- writesans "Tactic failed.", nl.

quit InGoal ff.

do G Goal Goal :- G.

basic_io PrintPred ReadPred Goal Tac :- PrintPred Goal, ReadPred Tac.

type  readtac0  (goal -> goal -> o) -> o.
readtac0 Tac :-
 prompting "Enter tactic: "
   (reread X\ (Tac = X;
	      (error (writesans "Input contains unknown parameter.")))).

readtac Tac :-
  once ( error_catch ( readtac0 Tac )
		     ( fl, writesans "Retry...", readtac Tac ) ).
