module lcprover.

% This module contains a specification for a theorem prover/proof
% checker for first-order classical logic.

import  lprf lists.

kind    seq             type.

type    '-->'           (list  form) -> (list form) -> seq.
type    '>-'            lprf -> seq -> o.

(initial A) >- (Gamma --> Delta) :- memb A Gamma, memb A Delta.

(and_r Q1 Q2) >- (Gamma --> Delta) :- memb (A and B) Delta,
                                      Q1 >- (Gamma --> (A::Delta)),
                                      Q2 >- (Gamma --> (B::Delta)).

(or_r Q) >- (Gamma --> Delta) :- memb (A or B) Delta,
                                 Q >- (Gamma --> (A::B::Delta)).

(imp_r Q) >- (Gamma --> Delta) :- memb (A imp B) Delta,
                                  Q >- ((A::Gamma) --> (B::Delta)).

(neg_r Q) >- (Gamma --> Delta) :- memb (neg A) Delta,
                                  Q >- ((A::Gamma) --> Delta).

(forall_r Q) >- (Gamma --> Delta) :-
   memb (forall A) Delta,
   pi Y\ ((Q Y) >- (Gamma --> ((A Y)::Delta))).

(exists_r T Q) >- (Gamma --> Delta) :- memb (exists A) Delta,
                                       Q >- (Gamma --> ((A T)::Delta)).

(and_l Q) >- (Gamma --> Delta) :- memb (A and B) Gamma,
                                  Q >- ((A::B::Gamma) --> Delta).

(imp_l Q1 Q2) >- (Gamma --> Delta) :- memb (A imp B) Gamma,
                                      Q1 >- (Gamma --> (A::Delta)),
                                      Q2 >- ((B::Gamma) --> Delta).

(forall_l T Q) >- (Gamma --> Delta) :- memb (forall A) Gamma,
                                       Q >- (((A T)::Gamma) --> Delta).

(neg_l Q) >- (Gamma --> Delta) :- memb (neg A) Gamma,
                                  Q >- (Gamma --> (A::Delta)).

(or_l Q1 Q2) >- (Gamma --> Delta) :- memb (A or B) Gamma,
                                     Q1 >- ((A::Gamma) --> Delta),
                                     Q2 >- ((B::Gamma) --> Delta).

(exists_l Q) >- (Gamma --> Delta) :-
   memb (exists A) Gamma,
   pi Y\ ((Q Y) >- (((A Y)::Gamma) --> Delta)).
