module liprover.

% This module contains a specification for a theorem prover/proof
% checker for intuitionistic logic. The clauses specify the inference
% rules of a variant of the LJ sequential proof system similar to
% Dummet's L system.

import  lprf lists.

kind    seq             type.

type    '-->'           (list  form) -> form -> seq.
type    '>-'            lprf -> seq -> o.

(initial A) >- (Gamma --> A) :- memb A Gamma.

(and_r Q1 Q2) >- (Gamma --> (A and B)) :- Q1 >- (Gamma --> A),
                                          Q2 >- (Gamma --> B).

%(or_r Q) >- (Gamma --> (A or B)) :- Q >- (Gamma --> A);
%                                    Q >- (Gamma --> B).

(or_r1 Q) >- (Gamma --> (A or B)) :- Q >- (Gamma --> A).

(or_r2 Q) >- (Gamma --> (A or B)) :- Q >- (Gamma --> B).

(imp_r Q) >- (Gamma --> (A imp B)) :- Q >- ((A::Gamma) --> B).

(neg_r Q) >- (Gamma --> (neg A)) :- Q >- ((A::Gamma) --> false).

(forall_r Q) >- (Gamma --> (forall A)) :- pi Y\ ((Q Y) >- (Gamma --> (A Y))).

%(forall_r Q) >- (Gamma --> (forall A)) :- pi Y\ (Q >- (Gamma --> (A Y))).

%(exists_r Q) >- (Gamma --> (exists A)) :- sigma T\ (Q >- (Gamma --> (A T))).
%(exists_r Q) >- (Gamma --> (exists A)) :- Q >- (Gamma --> (A T)).

(exists_r T Q) >- (Gamma --> (exists A)) :- Q >- (Gamma --> (A T)).

(false_r Q) >- (Gamma --> A) :- Q >- (Gamma --> false).

(and_l Q) >- (Gamma --> C) :- memb (A and B) Gamma,
                              Q >- ((A::B::Gamma) --> C).

(imp_l Q1 Q2) >- (Gamma --> C) :- memb (A imp B) Gamma,
                                  Q1 >- (Gamma --> A),
                                  Q2 >- ((B::Gamma) --> C).

(forall_l T Q) >- (Gamma --> C) :- memb (forall A) Gamma,
                                   Q >- (((A T)::Gamma) --> C).

(neg_l Q) >- (Gamma --> false) :- memb (neg A) Gamma,
                                  Q >- (Gamma --> A).

(or_l Q1 Q2) >- (Gamma --> C) :- memb (A or B) Gamma,
                                 Q1 >- ((A::Gamma) --> C),
                                 Q2 >- ((B::Gamma) --> C).

(exists_l Q) >- (Gamma --> C) :- memb (exists A) Gamma,
                                 pi Y\ ((Q Y) >- (((A Y)::Gamma) --> C)).

(cut Q1 Q2) >- (Gamma --> C) :- Q1 >- (Gamma --> A),
                                Q2 >- ((A::Gamma) --> C).
