module lniprover.

% This module simultaneously builds NI and LI proofs. Under a depth-first
% interpreter, it can transform LI proofs to NI proofs.

import  nprf lprf lists.

kind    judg            type.

type    '#'     nprf -> form -> judg.
type    '-->'   (list judg) -> judg -> seq.
type    '>-'    lprf -> seq -> o.

(initial A) >- (Gamma --> P # A) :- memb (P # A) Gamma.

(and_r Q1 Q2) >- (Gamma --> (and_i P1 P2) # (A and B)) :-
   Q1 >- (Gamma --> P1 # A), Q2 >- (Gamma --> P2 # B).

(or_r1 Q) >- (Gamma --> (or_i1 P) # (A or B)) :- Q >- (Gamma --> P # A).

(or_r2 Q) >- (Gamma --> (or_i2 P) # (A or B)) :- Q >- (Gamma --> P # B).

(imp_r Q) >- (Gamma --> (imp_i P) # (A imp B)) :-
   pi PA\ (Q >- (((PA # A)::Gamma) --> (P PA) # B)).

(neg_r Q) >- (Gamma --> (neg_i P) # (neg A)) :-
   pi PA\ (Q >- (((PA # A)::Gamma) --> (P PA) # false)).

(forall_r Q) >- (Gamma --> (forall_i P) # (forall A)) :-
   pi Y\ ((Q Y) >- (Gamma --> (P Y) # (A Y))).

(exists_r T Q) >- (Gamma --> (exists_i T P) # (exists A)) :-
   Q >- (Gamma --> P # (A T)).

(false_r Q) >- (Gamma --> (false_i P) # A) :- Q >- (Gamma --> P # false).

(and_l Q) >- (Gamma --> PC # C) :- memb (P # (A and B)) Gamma,
   Q >- ((((and_e1 B P) # A)::((and_e2 A P) # B)::Gamma) --> PC # C).

(imp_l Q1 Q2) >- (Gamma --> PC # C) :- memb (P2 # (A imp B)) Gamma,
   Q1 >- (Gamma --> P1 # A),
   Q2 >- ((((imp_e A P1 P2) # B)::Gamma) --> PC # C).

(forall_l T Q) >- (Gamma --> PC # C) :- memb (P # (forall A)) Gamma,
   Q >- ((((forall_e T A P) # (A T))::Gamma) --> PC # C).

(neg_l Q) >- (Gamma --> (neg_e A P1 P2) # false) :-
   memb (P2 # (neg A)) Gamma, Q >- (Gamma --> P1 # A).

(or_l Q1 Q2) >- (Gamma --> (or_e A B P P1 P2) # C) :-
   memb (P # (A or B)) Gamma,
   pi PA\ (Q1 >- (((PA # A)::Gamma) --> (P1 PA) # C)),
   pi PB\ (Q2 >- (((PB # B)::Gamma) --> (P2 PB) # C)).

(exists_l Q) >- (Gamma --> (exists_e A P1 P2) # B) :-
   memb (P1 # (exists A)) Gamma,
   pi Y\ (pi P\ ((Q Y) >- (((P # (A Y))::Gamma) --> (P2 Y P) # B))).
