% Proof normalization for NJ system (natural deduction for 
% intuitionistic logic).
% Works by finding first maximum segment, performing a reduction,
% and starting over at the root, until there are no more maximum segments.

module ndnorm.

import ndredex.

type    red1          nprf -> nprf -> o.
type    reduce        nprf -> nprf -> o.
type    ndnormalize   name -> nprf -> o.

red1 P1 P2 :- redex P1 P2.
red1 (and_i P1 P2) (and_i POut P2) :- red1 P1 POut.
red1 (and_i P1 P2) (and_i P1 POut) :- red1 P2 POut.
red1 (or_i1 P) (or_i1 POut) :- red1 P POut.
red1 (or_i2 P) (or_i2 POut) :- red1 P POut.
red1 (imp_i P) (imp_i POut) :- pi PA\ (red1 (P PA) (POut PA)).
red1 (forall_i P) (forall_i POut) :- pi Y\ (red1 (P Y) (POut T)).
red1 (exists_i T P) (exists_i T POut) :- red1 P POut.
red1 (and_e1 B P) (and_e1 B POut) :- red1 P POut.
red1 (and_e2 A P) (and_e2 A POut) :- red1 P POut.
red1 (imp_e A P1 P2) (imp_e A POut P2) :- red1 P1 POut.
red1 (imp_e A P1 P2) (imp_e A P1 POut) :- red1 P2 POut.
red1 (or_e A B P1 P2 P3) (or_e A B POut P2 P3) :- red1 P1 POut.
red1 (or_e A B P1 P2 P3) (or_e A B P1 POut P3) :-
   pi PA\ (red1 (P2 PA) (POut PA)).
red1 (or_e A B P1 P2 P3) (or_e A B P1 P2 POut) :-
   pi PB\ (red1 (P3 PB) (POut PB)).
red1 (forall_e T A P) (forall_e T A POut) :- red1 P POut.
red1 (exists_e A P1 P2) (exists_e A POut P2) :- red1 P1 POut.
red1 (exists_e A P1 P2) (exists_e A P1 POut) :-
   pi Y\ (pi P\ (red1 (P2 Y P) (POut Y P))).

reduce PIn POut :-
  red1 PIn PMid,
  writesans "*****Intermediate Proof: ", nl,
  write PMid, nl, nl,
  reduce PMid POut.
reduce P P.

ndnormalize Name POut :-
  nproofex Name PIn,
  reduce PIn POut.


%non-normal proof
nproofex cases3
  (imp_i P1\ (or_e (p1 a) (p3 b)
                   (and_e1 (forall X\ ((p1 X) imp (p2 X))) P1)
                   P2\ (exists_i a
                        (imp_e (p1 a) P2
                              (forall_e a X\ ((p1 X) imp (p3 X))
                         (imp_e ((forall X\ ((p1 X) imp (p2 X))) and
                                 (forall X\ ((p2 X) imp (p3 X))))
                                (and_e2 ((p1 a) or (p3 b)) P1)
                                (imp_i P3\ (forall_i X\ (imp_i P4\
                                 (imp_e (p2 X)
                                        (imp_e (p1 X) P4
                                               (forall_e X
                                                    X\ ((p1 X) and (p2 X))
                                                    (and_e1
                                                    (forall X\
                                                     ((p2 X) imp (p3 X))) P3)))
                                        (forall_e X X\ ((p2 X) and (p3 X))
                                             (and_e2 (forall X\
                                                      ((p1 X) imp (p2 X)))
                                                     P3))))))))))
                   P5\ (exists_i b P5))).

test P :- ndnormalize cases3 P.
