% Reductions for proof normalization for NJ system (natural deduction for 
% intuitionistic logic).

module ndredex.

import nprf.

type    redex   nprf -> nprf -> o.

% eliminate maximal formulas
redex (and_e1 B (and_i P1 P2)) P1.
redex (and_e2 A (and_i P1 P2)) P2.
redex (imp_e A P1 (imp_i P2)) (P2 P1).
redex (or_e A B (or_i1 P1) P2 P3) (P2 P1).
redex (or_e A B (or_i2 P1) P2 P3) (P3 P1).
redex (forall_e T A (forall_i P)) (P T).
redex (exists_e A (exists_i T P1) P2) (P2 T P1).

redex (and_e1 B (false_i P)) (false_i P).
redex (and_e2 A (false_i P)) (false_i P).
redex (imp_e A (false_i P1) P2) (false_i P1).
redex (or_e A B (false_i P1) P2 P3) (false_i P).
redex (forall_e T A (false_i P)) (false_i P).
redex (exists_e A (false_i P1) P2) (false_i P1).

% eliminate E-segments
redex (and_e1 C (or_e A B P1 P2 P3))
      (or_e A B P1 (Q\ (and_e1 C (P2 Q))) (Q\ (and_e1 C (P3 Q)))).
redex (and_e2 C (or_e A B P1 P2 P3))
      (or_e A B P1 (Q\ (and_e2 C (P2 Q))) (Q\ (and_e2 C (P3 Q)))).
redex (or_e C D (or_e A B P1 P2 P3) P4 P5)
      (or_e A B P1 (Q\ (or_e C D (P2 Q) P4 P5))
                   (Q\ (or_e C D (P3 Q) P4 P5))).
redex (imp_e C P4 (or_e A B P1 P2 P3))
      (or_e A B P1 (Q\ (imp_e C P4 (P2 Q))) (Q\ (imp_e C P4 (P3 Q)))).
redex (forall_e T C (or_e A B P1 P2 P3))
      (or_e A B P1 (Q\ (forall_e T C (P2 Q))) (Q\ (forall_e T C (P3 Q)))).
redex (exists_e C (or_e A B P1 P2 P3) P4)
      (or_e A B P1 (Q\ (exists_e C (P2 Q) P4)) (Q\ (exists_e C (P3 Q) P4))).

redex (and_e1 C (exists_e A P1 P2))
      (exists_e A P1 (Y\Q\ (and_e1 C (P2 Y Q)))).
redex (and_e2 C (exists_e A P1 P2))
      (exists_e A P1 (Y\Q\ (and_e2 C (P2 Y Q)))).
redex (or_e C D (exists_e A P1 P2) P4 P5)
      (exists_e A P1 (Y\Q\ (or_e C D (P2 Y Q) P4 P5))).
redex (imp_e C P4 (exists_e A P1 P2))
      (exists_e A P1 (Y\Q\ (imp_e C P4 (P2 Y Q)))).
redex (forall_e T C (exists_e A P1 P2))
      (exists_e A P1 (Y\Q\ (forall_e T C (P2 Y Q)))).
redex (exists_e C (exists_e A P1 P2) P4)
      (exists_e A P1 (Y\Q\ (exists_e C (P2 Y Q) P4))).

%eliminate redundant applications of or-E and exists-E
redex (or_e A B P1 Q\P2 P3) P2.
redex (or_e A B P1 P2 Q\P3) P3.
redex (exists_e A P1 Y\Q\P2) P2.
