module ndtac.

%  Below are the definition of the primitive tactics for a fragment
%  of first-order logic.  The proof objects which are built are in 
%  the form of natural deduction proofs.

import  ndgoal lists.

type    close_tac       int -> goal -> goal -> o.
type    and_i_tac       goal -> goal -> o.
type    or_i1_tac       goal -> goal -> o.
type    or_i2_tac       goal -> goal -> o.
type    imp_i_tac       goal -> goal -> o.
type    neg_i_tac       goal -> goal -> o.
type    forall_i_tac    goal -> goal -> o.
type    exists_i_tac    goal -> goal -> o.
type    false_i_tac     goal -> goal -> o.
type    and_e_tac       int -> goal -> goal -> o.
type    imp_e_tac       int -> goal -> goal -> o.
type    neg_e_tac       int -> goal -> goal -> o.
type    forall_e_tac    int -> goal -> goal -> o.
type    or_e_tac        int -> goal -> goal -> o.
type    exists_e_tac    int -> goal -> goal -> o.
type    and_e_tacr      int -> goal -> goal -> o.
type    imp_e_tacr      int -> goal -> goal -> o.
type    neg_e_tacr      int -> goal -> goal -> o.
type    forall_e_tacr   int -> goal -> goal -> o.
type    or_e_tacr       int -> goal -> goal -> o.
type    exists_e_tacr   int -> goal -> goal -> o.

close_tac N (Gamma --> P # A) tt :- nth_item N (P # A) Gamma.

and_i_tac  (Gamma --> (and_i P1 P2) # (A and B))
           ((Gamma --> P1 # A) && (Gamma --> P2 # B)).

or_i1_tac  (Gamma --> (or_i1 P) # (A or B))  (Gamma --> P # A).

or_i2_tac  (Gamma --> (or_i2 P) # (A or B))  (Gamma --> P # B).

imp_i_tac  (Gamma --> (imp_i P) # (A imp B))
           (all PA\ (((PA # A)::Gamma) --> (P PA) # B)).

neg_i_tac  (Gamma --> (neg_i P) # (neg A))
           (all PA\ (((PA # A)::Gamma) --> (P PA) # false)).

forall_i_tac  (Gamma --> (forall_i P) # (forall A))
              (all Y\ (Gamma --> (P Y) # (A Y))).

exists_i_tac  (Gamma --> (exists_i T P) # (exists A)) (Gamma --> P # (A T)).

false_i_tac  (Gamma --> (false_i P) # A)  (Gamma --> P # false).

and_e_tac N (Gamma --> PC # C)
            ((((and_e1 B P) # A)::((and_e2 A P) # B)::Gamma) --> PC # C) :-
   nth_item N (P # (A and B)) Gamma.

imp_e_tac N (Gamma --> PC # C)
            ((Gamma --> P1 # A) && ((((imp_e A P1 P2) # B)::Gamma) --> PC # C)) :-
   nth_item N (P2 # (A imp B)) Gamma.

neg_e_tac N (Gamma --> PC # C)
            ((Gamma --> P1 # A) &&
             ((((neg_e A P1 P2) # false)::Gamma) --> PC # C)) :-
   nth_item N (P2 # (neg A)) Gamma.

forall_e_tac N (Gamma --> PC # C)
               ((((forall_e T A P) # (A T))::Gamma) --> PC # C) :-
   nth_item N (P # (forall A)) Gamma.

or_e_tac N (Gamma --> (or_e A B P P1 P2) # C)
           ((all PA\ (((PA # A)::Gamma) --> (P1 PA) # C)) &&
            (all PB\ (((PB # B)::Gamma) --> (P2 PB) # C))) :-
   nth_item N (P # (A or B)) Gamma.

exists_e_tac N (Gamma --> (exists_e A P1 P2) # B)
               (all Y\ (all P\ (((P # (A Y))::Gamma) --> (P2 Y P) # B))) :-
   nth_item N (P1 # (exists A)) Gamma.

and_e_tacr N (Gamma --> PC # C)
             ((((and_e1 B P) # A)::((and_e2 A P) # B)::Gamma1) --> PC # C) :-
   nth_and_rest N (P # (A and B)) Gamma Gamma1.

imp_e_tacr N (Gamma --> PC # C)
             ((Gamma --> P1 # A) && ((((imp_e A P1 P2) # B)::Gamma1) --> PC # C)) :-
   nth_and_rest N (P2 # (A imp B)) Gamma Gamma1.

neg_e_tacr N (Gamma --> PC # C)
             ((Gamma --> P1 # A) &&
              ((((neg_e A P1 P2) # false)::Gamma1) --> PC # C)) :-
   nth_and_rest N (P2 # (neg A)) Gamma Gamma1.

forall_e_tacr N (Gamma --> PC # C)
                ((((forall_e T A P) # (A T))::Gamma1) --> PC # C) :-
   nth_and_rest N (P # (forall A)) Gamma Gamma1.

or_e_tacr N (Gamma --> (or_e A B P P1 P2) # C)
            ((all PA\ (((PA # A)::Gamma1) --> (P1 PA) # C)) &&
             (all PB\ (((PB # B)::Gamma1) --> (P2 PB) # C))) :-
   nth_and_rest N (P # (A or B)) Gamma Gamma1.

exists_e_tacr N (Gamma --> (exists_e A P1 P2) # B)
                (all Y\ (all P\ (((P # (A Y))::Gamma1) --> (P2 Y P) # B))) :-
   nth_and_rest N (P1 # (exists A)) Gamma Gamma1.
