module ninormal1.

% This module contains a specification of a theorem prover for the NJ
% natural deduction proof system for first-order logic as in Prawitz 1965.
% Only normal proofs are constructed.
% This module is the same as 'ninormal.mod' except that assumptions are
% stored in explicit context lists rather than implicitly using
% meta-level implication.

import  nprf lists.

kind    judg            type.

type    '#'     nprf -> form -> judg.
type    '-->'   (list judg) -> judg -> o.

Gamma --> P # A :- memb (P # A) Gamma.

Gamma --> (and_i P1 P2) # (A and B) :- Gamma --> P1 # A, 
                                       Gamma --> P2 # B.

Gamma --> (or_i1 P) # (A or B) :- Gamma --> P # A.

Gamma --> (or_i2 P) # (A or B) :- Gamma --> P # B.

Gamma --> (imp_i P) # (A imp B) :-
   pi PA\ (((PA # A)::Gamma) --> (P PA) # B).

Gamma --> (neg_i P) # (neg A) :-
   pi PA\ (((PA # A)::Gamma) --> (P PA) # false).

Gamma --> (forall_i P) # (forall A) :-
   pi Y\ (Gamma --> (P Y) # (A Y)).

Gamma --> (exists_i T P) # (exists A) :- Gamma --> P # (A T).

Gamma --> (false_i P) # A :- Gamma --> P # false.

Gamma --> PC # C :- memb (P # (A and B)) Gamma,
   (((and_e1 B P) # A)::((and_e2 A P) # B)::Gamma) --> PC # C.

Gamma --> PC # C :- memb (P2 # (A imp B)) Gamma,
   Gamma --> P1 # A,
   (((imp_e A P1 P2) # B)::Gamma) --> PC # C.

Gamma --> PC # C :- memb (P # (forall A)) Gamma,
   (((forall_e T A P) # (A T))::Gamma) --> PC # C.

Gamma --> (neg_e A P1 P2) # false :- memb (P2 # (neg A)) Gamma,
                                     Gamma --> P1 # A.

Gamma --> (or_e A B P P1 P2) # C :- memb (P # (A or B)) Gamma,
   pi PA\ (((PA # A)::Gamma) --> (P1 PA) # C),
   pi PB\ (((PB # B)::Gamma) --> (P2 PB) # C).

Gamma --> (exists_e A P1 P2) # B :- memb (P1 # (exists A)) Gamma,
   pi Y\ (pi P\ (((P # (A Y))::Gamma) --> (P2 Y P) # B)).
