module niprover.

% This module contains a specification of a theorem prover for the I
% natural deduction proof system for first-order intuitionistic logic
% as in Prawitz 1965.

import  nprf.

type    '#'     nprf -> form -> o.

(and_i P1 P2) # (A and B) :- P1 # A, P2 # B.
(or_i1 P) # (A or B) :- P # A.
(or_i2 P) # (A or B) :- P # B.
(imp_i P) # (A imp B) :- pi PA\ ((PA # A) => ((P PA) # B)).
(neg_i P) # (neg A) :- pi PA\ ((PA # A) => ((P PA) # false)).
(exists_i T P) # (exists A) :- P # (A T).
(forall_i P) # (forall A) :- pi Y\ ((P Y) # (A Y)).
(false_i P) # A :- P # false.
(and_e1 B P) # A :- P # (A and B).
(and_e2 A P) # B :- P # (A and B).
(or_e A B P P1 P2) # C :- P # (A or B),
                          pi PA\ ((PA # A) => ((P1 PA) # C)),
                          pi PB\ ((PB # B) => ((P2 PB) # C)).
(imp_e A P1 P2) # B :- P1 # A, P2 # (A imp B).
(neg_e A P1 P2) # false :- P1 # A, P2 # (neg A).
(exists_e A P1 P2) # B :- P1 # (exists A),
                          pi Y\ (pi P\ ((P # (A Y)) => ((P2 Y P) # B))).
(forall_e T A P) # (A T) :- P # (forall A).
