 
module tail_rec_ebg.

% switch (warning type_unify) off.

import metaebg.


kind   term			type.


type   ife			term -> term -> term -> term.
type   lam			(term -> term) -> term.
type   appl			term -> term -> term.
type   fix			(term -> term) -> term.
type   equals			term -> term -> term.

type   zero			term.
type   one			term.
type   times 			term -> term -> term.
type   minus		    	term -> term -> term.

type   nil_			term.
type   cons_			term -> term -> term.
type   null			term -> term.
type   car			term -> term.
type   cdr			term -> term.
type   append			term -> term -> term.


type   associative		(term -> term -> term) -> o.
type   commutative		(term -> term -> term) -> o.
type   left_identity		(term -> term -> term) -> term -> o.
type   right_identity		(term -> term -> term) -> term -> o.


type   insert_lam	
       (term -> term) -> term -> term -> o.
type   add_oper_rid1		
       (term -> term -> term) -> ((term -> term) -> term) -> term -> term -> o.
type   abstract_arg    
       (term -> term -> term) -> (term -> term) -> (term -> term) -> 
             term -> term -> o.
type   name_fn
       (term -> term) -> term -> term -> o.
type   unfold 
       (term -> term) -> term -> term -> o.
type   reduce_1
       ((term -> term) -> term) -> term -> term -> o.
type   dist_ife_2
       (term -> term -> term) -> 
             ((term -> term -> term) -> term) -> term -> term -> o.
type   left_id_2
       (term -> term -> term) -> 
             ((term -> term -> term) -> term) -> term -> term -> o.	     
type   assoc_2 
       (term -> term -> term) ->  
             ((term -> term -> term) -> term) -> term -> term -> o.
type   fold_two_3
       ((term -> term -> term -> term) -> term) ->
              (term -> term) -> (term -> term -> term -> term) -> 
	      term -> term -> term -> o.


type   derv	      (term -> term -> term) -> term -> term -> o.
type   getfact	      term -> o.
type   getrev         term -> o.
type   getdiff        term -> o.




 %%  Transformation Rules  
 %%     The parameter C is a higher-order variable containing context, that
 %%      is, it determines where the transformation is to be applied. 


hyp (box (pi C\ (pi G\ (
insert_lam     C
    (C (fix F\ (lam N\ (G F N))))
    (C (lam N1\ (appl (fix F\ (lam N\ (G F N))) N1)))
)))).

hyp (box (pi C\ (pi G\ (pi Op\ (pi A\ (
add_oper_rid1  Op   C
    (C (X\ (G X)))
    (C (X\ (Op (G X) A)))                      :- right_identity Op A
)))))).

hyp (box (pi C1\ (pi C2\ (pi Op\ (pi A\ (
abstract_arg   Op   C1   C2 
    (C1 (C2 A))
    (C1 (appl (lam M\ (C2 M)) A))
)))))). 

hyp (box (pi C\ (pi G\ (
name_fn	       C 
    (C G)
    (C (fix Fnew\ G))
)))).

hyp (box (pi C\ (pi G\ (
unfold         C
    (C (fix F\ (G F)))
    (C (G (fix F\ (G F))))
)))).

hyp (box (pi C\ (pi G\ (
reduce_1       C
    (C (X\ (appl (lam N\ (G N)) X)))
    (C (X\ (G X)))
)))).

hyp (box (pi C\ (pi Op\ (pi Bool\ (pi E1\ (pi E2\ (pi H\ (
dist_ife_2     Op   C
    (C  (X\Y\ (Op (ife (Bool X Y) (E1 X Y) (E2 X Y)) (H X Y))))
    (C  (X\Y\ (ife (Bool X Y) (Op (E1 X Y) (H X Y))
		              (Op (E2 X Y) (H X Y)))))
)))))))).

hyp (box (pi C\ (pi H\ (pi Op\ (pi A\ (
left_id_2      Op   C
    (C  (X\Y\ (Op A (H X Y))))
    (C  (X\Y\ (H X Y)))                         :- left_identity Op A
)))))).

hyp (box (pi C\ (pi G\ (pi Op\ (pi H1\ (pi H2\ (pi H3\ (
assoc_2        Op   C
    (C  (X\Y\ (Op (Op (H1 X Y) (H2 X Y)) (H3 X Y))))
    (C  (X\Y\ (Op (H1 X Y) (Op (H2 X Y) (H3 X Y))))) 
					        :- associative Op
)))))))).

hyp (box (pi C1\ (pi C2\ (pi C3\ (pi G\ (pi H1\ (pi H2\ (
fold_two_3     C1   C2   C3
    (C2 (fix F\ (lam M\ (lam N\ (C3 G N M)))))
    (C1 (F\X\Y\ (C3 G (H1 X Y) (H2 X Y))))
    (C1 (F\X\Y\ (appl (appl F (H2 X Y)) (H1 X Y))))
)))))))).




%%  Metaprogram to apply transformations.
%%    This one replaces standard recursion of a certain form (single argument,
%%    associative operator, if-then-else, etc) with tail-recursion.

hyp (box (pi Op\ (pi F0\ (pi F1\ (pi F2\ (pi F3\ (pi F4\ (pi F5\ 
         (pi F6\ (pi F7\ (pi F8\ (pi F9\ (pi F10\ 
         (pi W\  (pi W0\ (pi W1\ (pi W2\ (pi W3\ (
derv Op F0 F10 :- 
  insert_lam         G\G
		     F0 F1,
  add_oper_rid1      Op  
		     G\(lam N\ (G N))   
		     F1 F2,
  abstract_arg	     Op
		     G\G
		     G\(lam N\ (Op (W0 N) G))
		     F2 F3,
  name_fn            G\(appl G W)
		     F3 F4,
  unfold             G\(appl (fix F1\ (lam M\ (lam N\ 
		            (Op (appl G N) M)))) W)
		     F4 F5,
  reduce_1	     G\(appl (fix F1\ (lam M\ (lam N\ (Op (G N) M)))) W)
		     F5 F6,
  dist_ife_2         Op
		     G\(appl (fix F1\ (lam M\ (lam N\ (G M N)))) W)
		     F6 F7,
  left_id_2          Op
		     G\(appl (fix F1\ (lam M\ (lam N\ 
		         (ife (W1 M N) (G M N) (W3 M N))))) W)
		     F7 F8,
  assoc_2            Op
		     G\(appl (fix F1\ (lam M\ (lam N\ 
		         (ife (W1 M N) (W2 M N) (G M N))))) W)
	             F8 F9,
  fold_two_3	     G\(appl (fix F1\ (lam M\ (lam N\ 
		         (ife (W1 M N) (W2 M N) (G F1 M N))))) W)
	             G\(appl G W)
		     G\H1\H2\(Op (appl G H1) H2)
		     F4 F9 F10
  ))))))))))))))))))).




%% Example programs.


hyp (associative times).
hyp (commutative times).
hyp (left_identity  times one).
hyp (right_identity times one).

 %% The following used for application of generalizations.
 (associative times).
 (commutative times).
 (left_identity  times one).
 (right_identity times one).

getfact   (fix Fact\ (lam N\ 
	    (ife (equals N zero) one (times (appl Fact (minus N one)) N)))).





hyp (associative    append).
hyp (left_identity  append nil_).
hyp (right_identity append nil_).

 (associative    append).
 (left_identity  append nil_).
 (right_identity append nil_).


getrev    (fix Rev\ (lam L\ 
            (ife (null L) nil_ (append (appl Rev (cdr L)) (cons_ (car L) nil_))))).







hyp (right_identity minus zero).

 (right_identity minus zero).


getdiff	  (fix Diff\ (lam L\
            (ife (null L) zero (minus (car L) (appl Diff (cdr L)))))).
	  





%% Standard queries. 

%     Apply meta-program to fact.

%  getfact F, dosolve (derv times F Fout) GG DD.

%  getrev  F, dosolve (derv append F Fout) GG DD.

%  getrev  F, dosolve (derv Append F Fout) GG DD.   %%% Works fine



%     Apply resulting generalization to rev.

  
% getfact F, dosolve (derv times F Fout) GG DD,
% getrev R, ((DD => GG) => (derv Append R Rout)).


%     Attempt to apply resulting generalization to diff.  


% getfact F, dosolve (derv times F Fout) GG DD,            
% getdiff R, !, ((DD => GG) => (derv Append R Rout)).






 %%  Easy forms of above.


derv_fact F Fout G GG DD  :- getfact F, 
			     G = (derv times F Fout), 
			     dosolve G GG DD.

derv_rev F Fout G GG DD  :- getrev F, 
			    G = (derv append F Fout), 
			    dosolve G GG DD.



 
derv_fact2 F Fout :- getfact F, 
		   derv_fact F1 F1out G GG DD, 
		   (DD => GG) => (derv times F Fout).

derv_rev2 F Fout :- getrev F, 
		   derv_rev F1 F1out G GG DD, 
		   (DD => GG) => (derv append F Fout).



  % The following do not yet work!

derv_gen_rev F Fout :- getrev F, 
		   derv_fact F1 F1out G GG DD, 
		   (DD => GG) => (derv append F Fout).

derv_gen_fact F Fout :- getfact F, 
		   derv_rev F1 F1out G GG DD, 
		   (DD => GG) => (derv times F Fout).



derv_gen_diff F Fout :- getdiff F, 
		    derv_fact F1 F1out G GG DD, 
		    (DD => GG) => (derv minus F Fout).








