%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%	CAM : Categorical Abstract Machine		  %%%
%%%	Test Cases for translator/evaluator		  %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

module camtest.

import mldecl camdecl camml cameval mlexam.

type	sample		int -> tm -> o.
type	samplecode	int -> prog -> o.
type	codegen		string -> prog -> o.
type	codeexec	string -> val -> o.

doc 	sample	"Sample code fragments.".

sample 1  (# 3).
sample 2  tt.
sample 3  (cond tt (# 3) (# 4)).
sample 4  (&& (# 3) tt).
sample 5  (let Id\Id (# 3)).
sample 6  (lamb Id\Id).
sample 7  (@ (lamb Id\Id) (# 3)).
sample 8  (@ (@ == (# 3)) (# 3)).
sample 9  (@ (@ plus (# 3)) (# 4)).
sample 10 (@ (@ minus (# 3)) (# 4)).
sample 11 (@ (@ times (# 3)) (# 4)).
sample 12 (@ (@ cns (# 1)) nill).
sample 13 (@ hd (@ (@ cns (# 1)) nill)).
sample 14 (@ tl (@ (@ cns (# 1)) nill)).
sample 15 (@ empty (@ (@ cns (# 1)) nill)).
sample 16 (@ empty nill).



samplecode 1 C  :- sample 1 E,  translate E C.
samplecode 2 C  :- sample 2 E,  translate E C.
samplecode 3 C  :- sample 3 E,  translate E C.
samplecode 4 C  :- sample 4 E,  translate E C.
samplecode 5 C  :- sample 5 E,  translate E C.
samplecode 6 C  :- sample 6 E,  translate E C.
samplecode 7 C  :- sample 7 E,  translate E C.
samplecode 8 C  :- sample 8 E,  translate E C.
samplecode 9 C  :- sample 9 E,  translate E C.
samplecode 10 C :- sample 10 E, translate E C.
samplecode 11 C :- sample 11 E, translate E C.
samplecode 12 C :- sample 12 E, translate E C.
samplecode 13 C :- sample 13 E, translate E C.
samplecode 14 C :- sample 14 E, translate E C.
samplecode 15 C :- sample 15 E, translate E C.
samplecode 16 C :- sample 16 E, translate E C.

codegen "fact"    C :- fact1 F, translate (@ F (# 2)) C.
codegen "evenodd" C :- evenodd1 F, translate (@ (@ fst F) (# 3)) C.
codegen "append"  C :- app1 A, l12 L12, l34 L34,
			translate (@ (@ A L12) L34) C.
codegen "gcd"     C :- gcd1 G,  translate (@ (@ G (# 2)) (# 4)) C.

codegen "len"     C :- len1 L, l12 L12, translate (@ L L12) C.

%%% map the function "+1" over the list [1,2] %%%
codegen "map"     C :- map1 M, l12 L12,
		       translate (@ (@ M (lamb N\(@ (@ plus N) (# 1)))) L12) C.



%-----------------------------------------------------------------------%


%%% Generate and Execute the code
%%% Try Prog = "fact", "evenodd", "append", "gcd", "len", "map"
%%%
%%% The answers should be:
%%%	"fact":		V == (# 2)
%%%	"evenodd":	V == cff
%%%	"append":	V == clist (## 1) (clist (## 2) 
%%%				(clist (## 3) (clist (## 4) cnil)))
%%%	"gcd":		V == (# 2)
%%%	"len":		V == (# 2)
%%%	"map":		V == clist (## 2) (clist (## 3) cnil)

codeexec Prog  V :- codegen Prog C, exec C V.

