%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%    mini-ML : Signature                                %%%
%%%    Declaration of Type and Expression Constructors    %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

module mldecl.


%%% Kinds for object terms and types
kind  tm   type.                       %%% meta-type for terms
kind  tp   type.                       %%% meta-type for types

%%% Type Constructors
type  mand  tp -> tp -> tp.            %%% product space
type  -->   tp -> tp -> tp.            %%% function space
type  mbool tp.                        %%% meta-type bool
type  mint  tp.                        %%% meta-type int
type  mlist tp -> tp.                  %%% meta-type list constructor

%%% Term Constructors
type  lamb  (tm -> tm) -> tm.          %%% Lambda Abstraction
type  cond   tm -> tm -> tm -> tm.     %%% Conditional
type  &&    tm -> tm -> tm.            %%% Products
type  @     tm -> tm -> tm.            %%% Application
type  let   (tm -> tm) -> tm -> tm.    %%% Let
type  fix   (tm -> tm) -> tm.          %%% Fixed Point
type  #     int -> tm.                 %%% Coerces int to mint

%%% Primitives/Constants
type  tt    tm.                        %%% true
type  ff    tm.                        %%% false
type  fst   tm.                        %%% first projection
type  snd   tm.                        %%% first projection
type  cns   tm.                        %%% list constructor
type  nill  tm.                        %%% empty list
type  hd    tm.                        %%% head-of-list function
type  tl    tm.                        %%% tail-of-list function
type  empty tm.                        %%% empty-list function
type  ==    tm.                        %%% equality function
type  !=    tm.                        %%% inequality function
type  lt    tm.                        %%% integer <
type  gt    tm.                        %%% integer >
type  plus  tm.                        %%% integer +
type  minus tm.                        %%% integer -
type  times tm.                        %%% integer *


%%% need list membership predicate
type member	A -> (list A) -> o.
member X (cons X L) :- !.
member X (cons Y L) :- member X L.

%%%   End of module mldecl   %%%

