%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%        mini-ML : Evaluation Procedure                 %%%
%%%        (eval Exp V) succeeds if Exp evaluates to V.   %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

module mleval.

import mldecl.

type eval             tm -> tm -> o.
type evalbinaryop     tm -> tm -> tm -> tm -> o.
type evalunaryop      tm -> tm -> tm -> o.


eval (# N)  (# N).                               %%%  Numbers

eval tt tt.                                      %%%  Constants
eval ff ff.
eval nill nill.

eval (cond E1 E2 E3) C :-                        %%%  Conditional
        eval E1 B,
        (B = tt, eval E2 C, ! ;
                 eval E3 C).

eval (&& E1 E2) (&& C1 C2) :-                    %%% (6) Product
        eval E1 C1,
        eval E2 C2.

eval (lamb M) (lamb M).                          %%% (9) Abstraction

eval (@ E1 E2) C :-                              %%% (10) Application
        eval E1 (lamb M),
        eval E2 C2,
        eval (M C2) C.        

eval (let M E2) C :-                             %%% (11) Let
        eval E2 C2,
        eval (M C2) C.

eval (fix M) C :-                                %%% (12) Recursion
        eval (M (fix M)) C.


%%% Primitive unary operators %%%
eval (@ Op E1) C :-
        member Op (cons fst (cons snd (cons hd (cons tl (cons empty nil))))),
        eval E1 C1,
        evalunaryop Op C1 C.

%%%  Primitive binary operators %%%
eval (@ (@ Op E1) E2) C :-
        member Op (cons cns (cons == (cons != (cons lt (cons gt (cons plus
			(cons minus (cons times nil)))))))),
        eval E1 C1,
        eval E2 C2,
        evalbinaryop Op C1 C2 C.

evalunaryop fst (&& C1 C2) C1.                   %%% (7) First Projection
evalunaryop snd (&& C1 C2) C2.                   %%% (8) Second Projection
evalunaryop hd  (@ (@ cns C1) C2) C1.            %%% head of list
evalunaryop tl  (@ (@ cns C1) C2) C2.            %%% tail of list
evalunaryop empty nill tt.                       %%% empty-list function
evalunaryop empty (@ (@ cns C1) C2) ff.          %%%   ""
        
evalbinaryop cns C1 C2 (@ (@ cns C1) C2).        %%% list construction
evalbinaryop == C C tt.                          %%% term equality
evalbinaryop == C1 C2 ff.                        %%%   ""
evalbinaryop != C C ff.                          %%% term inequality
evalbinaryop != C1 C2 tt.                        %%%   ""
evalbinaryop lt (# N1) (# N2) T :-               %%% integer <
        (N1 < N2), T = tt, ! ; T = ff.
evalbinaryop gt (# N1) (# N2) T :-               %%% integer >
        (N1 > N2), T = tt, ! ; T = ff.
evalbinaryop plus (# N1) (# N2) (# N) :-         %%% integer +
        N is (N1 + N2).
evalbinaryop minus (# N1) (# N2) (# N) :-        %%% integer -
        N is (N1 - N2).
evalbinaryop times (# N1) (# N2) (# N) :-        %%% integer *
        N is (N1 * N2).

%%%   End of module mleval   %%%

