%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%     mini-ML : Type Inference                          %%%
%%%     (infer Exp Type) succeeds if Exp has type Type 	  %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

module mltype.

import mldecl.

type  infer   tm -> tp -> o.


%%% Numbers in parentheses correspond to the numbering given to the
%%% rules in figure 3.

infer (# N) mint.                          %%% (1) Numbers

infer tt mbool.                            %%% (2,3) Boolean constants
infer ff mbool.


infer (cond E1 E2 E3) T :-                 %%%  Conditional
        infer E1 mbool,
        infer E2 T,
        infer E3 T.

infer (&& E1 E2) (mand T1 T2) :-           %%%  Product Introduction
        infer E1 T1,
        infer E2 T2.

infer (lamb M) ( --> T1 T2) :-              %%% Abstraction
        pi C\(infer C T1 => infer (M C) T2).

infer (@ E1 E2) T2 :-                      %%%  Application
        infer E1 ( --> T1 T2),
        infer E2 T1.

infer (let M E2) T1 :-                     %%%  Let
        infer E2 T2,
        infer (M E2) T1.

infer  (fix M) T :-                        %%%  Recursion
        pi C\(infer C T => infer (M C) T).


%%% primitive operators %%%

infer fst (--> (mand T1 T2) T1).           %%%  First Projection
infer snd (--> (mand T1 T2) T2).           %%%  Second Projection

infer cns ( --> T (--> (mlist T) (mlist T))).  %%% list constructor
infer hd (--> (mlist T) T).                %%% head of list
infer tl (--> (mlist T) (mlist T)).        %%% tail of list
infer nill (mlist T).                      %%% the empty list
infer empty (--> (mlist T) mbool).         %%% empty-list function

infer == (--> T (--> T mbool)).            %%% term equality
infer != (--> T (--> T mbool)).            %%% term inequality
infer lt (--> mint (--> mint mbool)).      %%% integer <
infer gt (--> mint (--> mint mbool)).      %%% integer >
infer plus (--> mint (--> mint mint)).     %%% integer +
infer minus (--> mint (--> mint mint)).    %%% integer -
infer times (--> mint (--> mint mint)).    %%% integer *


%%%   End of module mltype   %%%

