% A meta-interpreter for LambdaProlog.
% This handles the most general case for implication in programs,
% and also higher-order predicates.
% It does NOT handle cut and only a very limited number of special predicates.
% Author: Frank Pfenning (fp@cs.cmu.edu)

%% This revision solves real LambdaProlog goals, instead of things of
%% type prop, which mirrors o.  Works in eLP.

module meta.

type  msolve     o -> o.
type  mhyp       o -> o.
type  match_atom o -> o -> o -> o.

index msolve	 1.
index mhyp	 1.
index match_atom 1.

msolve true      :- !.
msolve (G1 , G2) :- !, msolve G1, msolve G2.
msolve (G1 ; G2) :- !, (msolve G1; msolve G2).
msolve (D => G)  :- !, mhyp D => msolve G.
msolve (pi G)    :- !, pi X\ (msolve (G X)).
msolve (sigma G) :- !, msolve (G X).
msolve (once G)	 :- !, once (msolve G).
msolve !	 :- !, error (writesans "Metainterpreter cannot handle cut.
You may be able to use ``once'' instead.").
% An example on how to handle special predicates, if we wanted to:
% msolve (write X) :- !, write X.
msolve (M = N)   :- !, M = N.
msolve Atom      :- !, mhyp D,
	               match_atom D Atom Subgoal,
		       msolve Subgoal.

match_atom (D1 , D2) Atom Subgoal :- !,
    (match_atom D1   Atom Subgoal;
     match_atom D2   Atom Subgoal).

match_atom (D1 ; D2) Atom Subgoal :- !,
    error (writesans "Illegal disjunction in program: ", write (D1 ; D2)).

match_atom (G => D)  Atom (G , Subgoal) :- !,
    match_atom D     Atom Subgoal.

match_atom (pi D)    Atom Subgoal :- !,
    match_atom (D X) Atom Subgoal.

match_atom (sigma D) Atom Subgoal :- !,
    error (writesans "Illegal existential in program: ", write (sigma D)).

match_atom Atom      Atom true.
    % NOTE: no cut here, since the first and second argument to match_atom
    % may have multiple unifiers.  This is the only place where the unifier
    % in the object-language is called.  It can be generalized to
    % match_atom A Atom true :- object_unify A Atom.
