% A mock interpreter for Elf in LambdaProlog.
% It does not interpret cut or special predicates.
% This does not run because of calls to non-existent unification predicates,
% lftype_unify and lfterm_unify.
% Author: Frank Pfenning (fp@cs.cmu.edu)

module metaelf.

%% The LambdaProlog types.

kind  lftype	 type.
kind  lfterm	 type.

%% The language of types.

% type lfunit_type lftype
type  lfpi	 lftype -> (lfterm -> lftype) -> lftype.
type  lfsigma	 lftype -> (lfterm -> lftype) -> lftype.

%% The language of terms.

% type  unit_element lfterm.
type  pair	 lfterm -> lfterm -> lfterm.
type  lam	 lftype -> (lfterm -> lfterm) -> lfterm.

type  fst	 lfterm -> lfterm.
type  snd	 lfterm -> lfterm.
type  app	 lfterm -> lfterm -> lfterm.

%% The predicates implementing the interpreter.

type  esolve     lftype -> lfterm -> o.
type  ehyp       lftype -> lfterm -> o.
type  ematch_atom lftype -> lfterm -> lftype -> lfterm -> o -> o.

type  lftype_unify lftype -> lftype -> o.
type  lfterm_unify lfterm -> lfterm -> o.

doc   esolve
 "``esolve A M'' expects a type A and attempts to find a term M of this type.
It does not handle cut or special predicates.".

% esolve unit_type   unit_element :- !.
esolve (lfpi A B)    (lam A M ) :- !, pi X\(ehyp A X => esolve (B X) (M X)).
esolve (lfsigma A B) (pair M N) :- !, esolve A M, esolve (B M) N.
esolve Atom	   M :- open Atom, !.
esolve Atom	   M :- !, ehyp A X, 
		           ematch_atom A X Atom M MetaSubgoal,
			   MetaSubgoal.

doc    ematch_atom
 "``ematch_atom A N Atom M MetaSubgoal'' expects a type A with term N, and and
atomic type Atom with term M, and generates a MetaSubgoal that remains to be
solved, in order to solve Atom.  On backtracking, it enumerates MetaSubgoals,
until all the possibilities in A are exhausted, whereupon it fails.
  The fact that LambdaProlog is higher-order is convenient here, because the
MetaSubgoal can be used effectively to postpone subgoals, until is clear that
it would be worthwile trying to solve them.".

ematch_atom (lfpi A B)    N         Atom   M (esolve A X , MetaSubgoal) :- !,
  ematch_atom (B X)       (app N X) Atom   M MetaSubgoal.

ematch_atom (lfsigma A B) N	    Atom   M MetaSubgoal :-   % No cut here.
  ematch_atom A           (fst N)   Atom   M MetaSubgoal.

ematch_atom (lfsigma A B) N	    Atom   M MetaSubgoal :- !,
  ematch_atom (B (fst N)) (snd N)   Atom   M MetaSubgoal.	    

ematch_atom A		  N	    Atom   M true :- !,
  lftype_unify A Atom, lfterm_unify N M.
