%%% Some utilities for interaction with eLP.  Some of these used to be
%%% in elp.mod.
%%% Author: fp

module top_utils.

type	assume		(o -> o) -> o.	     % Assuming on top-level.
assume E :- E top.
% defined assume		interpreter.
doc     assume
 "``assume E'' applies E to top.  For example:
   ``assume (searching ^"./modules/^")''
will start a new top-level in which the subdirectory ^"modules^" is
searched when loading modules.".

%% Preferable is to 'pop' from the current top level.
type	untrace		opt -> o.
untrace Opt :- switch (tracing Opt) off.
% defined untrace      elp_switches.
doc     untrace
  "``untrace Opt'' starts a new top-level in which tracing of option Opt is off.".

%%% A few defined predicates for loading.

type	qload		string -> o.
% defined	qload		modules.
doc	qload
 "``qload Module'' (quiet load) is like ``load Module'', except that it
does not give warnings for multiple declarations or shadowing,
nor does it list the undeclared constants after the file has been loaded.".

qload Module :-
 switching (warning multiple_decl) off
  (switching show_undeclared_constants off (load Module)).

type	vload		string -> o.
% defined	vload		modules.
doc	vload
 "``vload Module'' (verbose load) is like ``load Module'', except that it will
give warning messages and list the undeclared constants after the file
has been loaded.".

vload Module :-
 switching (warning multiple_decl) on
  (switching show_undeclared_constants on (load Module)).
