%%% Type inference for the second-order polymorphic Lambda calculus.
%%% This is for diagnostic: we always build up the type from the bottom
%%% upwards, thus restricting the places where type inference can fail.
%%% Author: fp

module polydiag.
import polysig.

type  failure_diagnostic  tm -> ta -> o.
doc   failure_diagnostic
 "``failure_diagnostic U Alpha'' attempts to give a reasonable error message
as to why the type inference on U failed.".

failure_diagnostic U Alpha :-
  ditype U Beta,
  (Alpha = Beta;
   (fl, writesans "Top-level type checking error: the inferred type ",
    write Beta, writesans " is different from the passed type ",
    write Alpha, fail)).

type  ditype	tm -> ta -> o.
index ditype	1.

% It seems one would need the `var' predicate for a correct
% implementation of this check.
ditype thisisahack Alpha :- !,
  error (write "Illegal free variable in input.").

ditype (pmmlam     U) Alpha :- !,
  pi x\ (vartype x Beta => ditype (U x) Gamma),
  Alpha = (afun Beta Gamma).

ditype (mmlam Beta U) Alpha :- !,
  pi x\ (vartype x Beta => ditype (U x) Gamma),
  Alpha = (afun Beta Gamma).

ditype (mmapp U0 U1) Alpha :- !,
  ditype U1 Beta,
  ditype U0 Gamma,
  (Gamma = (afun Beta Delta);
   (fl, writesans "Type checking error: ", write U0,
    writesans " of type ", write Gamma, nl,
    writesans " applied as function to ", write U1,
    writesans " of type ", write Beta,
    fail)),
  Alpha = Delta.

ditype (amlam U) Alpha :- !,
   pi theta\ (ditype (U theta) (Beta theta)),
   Alpha = (del Beta).

ditype (pmaapp U    ) Alpha :- !,
  ditype U Delta,
  (Delta = (del Beta);
   (fl, writesans "Type checking error: ", write U,
    writesans " of type ", write Delta, nl,
    writesans " applied as function to unspecified type",
    fail)),
  Alpha = (Beta Gamma).

ditype (maapp U Gamma) Alpha :- !,
  ditype U Delta,
  (Delta = (del Beta);
   (fl, writesans "Type checking error: ", write U, 
    writesans " of type ", write Delta, nl,
    writesans " applied as function to type ", write Gamma,
    fail)),
  Alpha = (Beta Gamma).

ditype (cm U Beta) Alpha :- !,
  ditype U Gamma,
  (Beta = Gamma;
   (fl, writesans "Type checking error: ", write U,
    writesans " of type ", write Gamma, nl,
    writesans " was given explicit type ", write Beta,
    fail)),
  Alpha = Beta.

ditype X Alpha :- vartype X Beta, !,
   Alpha = Beta.

ditype X Alpha :- !,
    error (writesans "Unknown constant ", write X, nl).
