%%% Director Strings (see [Curien 86], pp 47-48) %%%

module director.

import substaux.

type dirtrans	tm -> dtm -> o.
type bracket	(string -> dtm) -> dtm -> o.
type substdir	dtm -> dtm -> dtm -> o.

doc dirtrans "(dirtrans T D) iff term T translates to D (director syntax).".
doc bracket  "(bracket \x.D E) iff [x]D = E (bracket abstraction).".
doc substdir "(substdir P Q R) iff P[x:=Q] = R using director terms.".

type newname    string -> dtm -> o.
type notfree    string -> dtm -> o.

%%% bracket abstraction for translating from higher-order term to director

dirtrans (app P Q)  (dapp D E nil) :-
	dirtrans P D,
	dirtrans Q E.

dirtrans (abs M) E :-
	pi C\ (pi D\ (dirtrans C (dvar D nil)  => dirtrans (M C) (F D)),
	bracket F E.

dirtrans (fv M) (F Y) :-
	pi C\ (pi X\ (pi D\ (dirtrans C (dvar X nil)  =>  dirtrans (M C) (F X),
		newname Y (F X)))).


newname X T :-
	member X (cons "A" (cons "B" (cons "C" (cons "D" (cons "E"
		 (cons "F" (cons "G" (cons "H" (cons "I" nil))))))))),
	notfree X T, !.

notfree X (dvar Y S) :- !, not (X = Y).
notfree X (`I S).
notfree X (dapp U V S) :- !,
	notfree X U,
	notfree X V.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bracket X\(dvar X Str) (`I (cons b Str)).
bracket X\(dvar Y Str) (dvar Y (cons n Str)).
bracket X\(`I Str)    (`I (cons n Str)).

bracket X\(dapp D E Str) (dapp D E (cons n Str)) :- !.		% neither (#)
bracket X\(dapp (FD X) E Str) (dapp D E (cons l Str)) :- !,	% left    (/)
	bracket FD D.
bracket X\(dapp D (FE X) Str) (dapp D E (cons r Str)) :- !,	% right   (\)
	bracket FE E.
bracket X\(dapp (FD X) (FE X) Str) (dapp D E (cons b Str)) :-	% both    (^)
	bracket FD D,
	bracket FE E.


substdir (`I (cons n Str)) E  (`I Str).
substdir (`I (cons b Str)) E  E.

substdir (dapp D1 D2 (cons n Str)) E  (dapp D1 D2 Str).		% neither
substdir (dapp D1 D2 (cons l Str)) E  (dapp D3 D2 Str) :-	% left
	substdir D1 E D3.
substdir (dapp D1 D2 (cons r Str)) E  (dapp D1 D3 Str) :-	% right
	substdir D2 E D3.
substdir (dapp D1 D2 (cons b Str)) E  (dapp D3 D4 Str) :-	% both
	substdir D1 E D3,
	substdir D2 E D4.
