module examples.
import substaux.

type hterm	string -> tm -> o.
type dbterm	string -> deb -> o.
type fterm      string -> ftm -> o.
type dirterm    string -> dtm -> o.

doc hterm "Example terms in higher-order syntax.".
doc dbterm "Example terms in debruijn syntax.".
doc fterm "Example terms in first-order syntax.".
doc dirterm "Example terms in director syntax.".

type subst	int -> tm -> o.
type fsubst	int -> ftm -> o.
type dsubst	int -> deb -> o.
type dirsubst	int -> dtm -> o.


%%% Various terms defined in higher-order syntax %%%
hterm "I" (abs X\X).
hterm "K" (abs X\(abs Y\ X)).
hterm "S" (abs X\(abs Y\(abs Z\(app (app X Z) (app Y Z))))).
hterm "III" (app (app (abs X\ (abs Y\(app Y X))) I) I) :- hterm "I" I.

hterm "0" (abs X\(abs F\ X)).
hterm "1" (abs X\(abs F\(app F X))).
hterm "2" (abs X\(abs F\(app F (app F X)))).
hterm "plus" (abs N\(abs M\(abs X\(abs F\(app (app N F) (app (app M F) X)))))).
hterm "times" (abs N\(abs M\(abs X\(abs F\(app (app N (app M F)) X))))).
hterm "2+2" (app (app Plus Two) Two) :- hterm "plus" Plus, hterm "2" Two.
hterm "2*2" (app (app Times Two) Two) :- hterm "Time" Times, hterm "2" Two.

%%% de Bruijn Terms %%%
dbterm "I" D :- hterm "I" I, substdb ==> dbtrans I D.
dbterm "K" D :- hterm "K" K, substdb ==> dbtrans K D.
dbterm "S" D :- hterm "S" S, substdb ==> dbtrans S D.

%%% First-order Terms %%%
fterm "I" D :- hterm "I" I, hftrans ==> ftrans I D.
fterm "K" D :- hterm "K" K, hftrans ==> ftrans K D.
fterm "S" D :- hterm "S" S, hftrans ==> ftrans S D.

%%% Director Terms (see [Curien 86]) %%%
dirterm "I" D :- hterm "I" I, director ==> dirtrans I D.
dirterm "K" D :- hterm "K" K, director ==> dirtrans K D.
dirterm "S" D :- hterm "S" S, director ==> dirtrans S D.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% And now the example term that we will perform substitution on  %%%
%%% (from [Curien 86], p.48:	(\x.(\z.zx)y)((\t.t)z)		   %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hterm "C" (fv Y\ (fv Z\ (app (abs X\ (app (abs Z\ (app Z X)) Y))
			      (app (abs T\T) Z)))).

%%%	(\x.(\z.zx)y)((\t.t)z)  (with free variables left unbound)
hterm "C1" (app (abs X\ (app (abs Z\ (app Z X)) Y))
		(app (abs T\T) Z)).


subst 0 V :- hterm "C1" (app (abs M) Q), sub0 ==> subst0 M Q V.

subst 1 V :- hterm "C1" (app (abs M) Q), sub1 ==> subst1 M Q V.

subst 2 V :- hterm "C1" (app (abs M) Q), sub2 ==> subst2 M Q V.

fsubst 3 V :- hterm "C" C, 
	      hftrans ==> ftrans C (fapp (fabs X S) W),
	      sub3 ==> subst3 X S W V.

fsubst 4 V :- hterm "C" C,
	      hftrans ==> ftrans C (fapp (fabs X S) W),
	      sub4 ==> subst4 X S W V.

fsubst 5 V :- hterm "C" C,
	      hftrans ==> ftrans C (fapp (fabs X S) W),
	      sub5 ==> subst5 X S W V.

dsubst 1 V :- hterm "C" C, 
	      subdb ==> (dbtrans C (app$ P Q), substdb P Q V).

dirsubst 1 V :- hterm "C" C,
	        director ==> (dirtrans C (dapp D E nil), substdir D E V).