module subdb.

import substaux.


type	dbtrans		tm -> deb -> o.
type	dbtrans1	int -> tm -> deb -> o.
type	has_depth	tm -> int -> o.

type	substdb		deb -> deb -> deb -> o.
type	substdb1	int -> deb -> deb -> deb -> o.
type	lift		int -> int -> deb -> deb -> o.

doc dbtrans "Translates from higher-order syntax to de Bruijn syntax.".
doc substdb  "(substdb \x.M P Q) if Q = M[x:=P] using de Bruijn notation.".

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% TRANSLATION FROM HIGHER-ORDER SYNTAX
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dbtrans P Q :- dbtrans1 0 P Q.

dbtrans1 D (abs M) (abs$ P) :- 
  pi C\ (has_depth C D => (D1 is D + 1, dbtrans1 D1 (M C) P)).

dbtrans1 D (app M N) (app$ P Q) :- dbtrans1 D M P, dbtrans1 D N Q.

dbtrans1 D X (deb E) :- has_depth X N, E is (D - N).

dbtrans1 D (fv M) P :-
  pi C\ (has_depth C D => (D1 is D + 1, dbtrans1 D1 (M C) P)).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SUBSTITUTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

substdb (abs$ P) Q R :- substdb1 1 P Q R.

substdb1 N (abs$ P) Q (abs$ R) :-
	N1 is N + 1,
	substdb1 N1 P Q R.

substdb1 N (app$ P Q) R (app$ S T) :-
	substdb1 N P R S,
	substdb1 N Q R T.

substdb1 N (deb M) P Q :- N = M, lift M 0 P Q.
substdb1 N (deb M) P (deb M) :- not (N = M).

lift M I (app$ P Q) (app$ S T) :-
	lift M I P S,
	lift M I Q T.

lift M I (abs$ P) (abs$ Q) :-
	I1 is I + 1,
	lift M I1 P Q.

lift M I (deb N) (deb N) :- N < I, !.
lift M I (deb N) (deb K) :- K is N + M.
