;;; -*- Mode: Lisp; Package: SLTERMG -*-
(in-package "SLTERM")  ;; creates package for abstract syntax. 

(in-package "SLTERMG")  ;; enters package for generated code.  

(use-package '("ERGOLISP" "OPER" "OCC" "TERM" "SORT" "SB-RUNTIME" "LANG" "NEWATTR"))


(export '())

(DEFPARAMETER SLTERM-KEYWORD-LIST
              '(SBST::|import| SBST::\. SBST::|)| SBST::|(| SBST::->
               SBST::|hacked\\ellided\\sltype| SBST::|type| SBST::|type|
               SBST::|module| SBST::|index| SBST::|index| SBST::|kind|
               SBST::|,| SBST::|;| SBST::=> SBST::|:-|
               SBST::|hacked\\reverse\\implies| SBST::==> SBST::= SBST::|is|
               SBST::|=:=| SBST::|=\\=| SBST::< SBST::> SBST::=< SBST::>=
               SBST::|::| SBST::+ SBST::- SBST::* SBST::|div| SBST::|mod|
               SBST::|hacked\\ellided\\slterm| SBST::|\\| SBST::|:|)) 
(DEFPARAMETER SLTERM-SINGLE-CHAR-OP-LIST '(#\, #\; #\) #\( #\. #\\)) 
(DEFPARAMETER SLTERM-MULTI-CHAR-OP-LIST '((#\: . |LEX-:|))) 
(DEFPARAMETER SLTERM-ALL-OPERATORS-LIST
              '(SBST::|::| SBST::|,| SBST::|;| SBST::|:-| SBST::|)| SBST::|(|
               SBST::\. SBST::|\\| SBST::|:|)) 
(DEFPARAMETER SLTERM-NEW-LINE-COMMENT-CHAR #\%) 
(DEFPARAMETER SLTERM-OPEN-COMMENT-CHAR NIL) 
(DEFPARAMETER SLTERM-CLOSE-COMMENT-CHAR NIL) 
(DEFPARAMETER SLTERM-ESCAPE-CHAR #\^) 
(DEFPARAMETER SLTERM-CASE-SENSITIVE T) 
(DEFPARAMETER SLTERM-STRING-CHAR #\") 
(DEFPARAMETER SLTERM-KEYWORD-CHAR #\') 
(DEFPARAMETER SLTERM-LITERAL-CHAR NIL) 
(DEFPARAMETER SLTERM-RESTRICTED-CHARS
              (REDUCE #'(LAMBDA (R
                                 S)
                          (UNION R S :TEST #'CHAR=))
                      (LIST SLTERM-SINGLE-CHAR-OP-LIST
                            (IF SLTERM-NEW-LINE-COMMENT-CHAR
                                (LIST SLTERM-NEW-LINE-COMMENT-CHAR))
                            (IF SLTERM-OPEN-COMMENT-CHAR
                                (LIST SLTERM-OPEN-COMMENT-CHAR))
                            (IF SLTERM-CLOSE-COMMENT-CHAR
                                (LIST SLTERM-CLOSE-COMMENT-CHAR))
                            (IF SLTERM-ESCAPE-CHAR (LIST SLTERM-ESCAPE-CHAR))
                            (IF SLTERM-STRING-CHAR (LIST SLTERM-STRING-CHAR))
                            (IF SLTERM-KEYWORD-CHAR (LIST SLTERM-KEYWORD-CHAR))
                            (IF SLTERM-LITERAL-CHAR (LIST SLTERM-LITERAL-CHAR))))) 
(DEFVAR *SLTERM-KEYWORD-TABLE* NIL) 
(DEFUN INIT-LEXER-AUX (LEXSTREAM)
  (INIT-LEXICAL-READTABLE LEXSTREAM :SINGLE-CHAR-OP-LIST
                          SLTERM-SINGLE-CHAR-OP-LIST :NEW-LINE-COMMENT-CHAR
                          SLTERM-NEW-LINE-COMMENT-CHAR :OPEN-COMMENT-CHAR
                          SLTERM-OPEN-COMMENT-CHAR :ESCAPE-CHAR
                          SLTERM-ESCAPE-CHAR :MULTI-CHAR-OP-LIST
                          SLTERM-MULTI-CHAR-OP-LIST)) 

(DEFUN INIT-LEXER (LEXSTREAM)
  (INIT-LEXER-AUX LEXSTREAM)
  (IF SLTERM-STRING-CHAR
      (LEXICAL-MAKE-MACRO LEXSTREAM SLTERM-STRING-CHAR #'READ-SB-STRING))
  (IF SLTERM-KEYWORD-CHAR
      (LEXICAL-MAKE-MACRO LEXSTREAM SLTERM-KEYWORD-CHAR #'READ-KEYWORD-STRING))
  (IF SLTERM-LITERAL-CHAR
      (LEXICAL-MAKE-MACRO LEXSTREAM SLTERM-LITERAL-CHAR #'READ-LITERAL))) 

(DEFUN |LEX-:| (STREAM SYMBOL)
  (DECLARE (IGNORE SYMBOL))
  (LET (HOLDCHAR)
    (SETF HOLDCHAR (LEXICAL-READ-CHAR STREAM :EOF))
    (IF (AND SLTERM-ESCAPE-CHAR (CHAR= HOLDCHAR SLTERM-ESCAPE-CHAR))
        (SETF HOLDCHAR (LEXICAL-READ-CHAR STREAM :EOF)))
    (COND ((CHAR= HOLDCHAR #\:)
           'SBST::|::|)
          ((CHAR= HOLDCHAR #\-)
           'SBST::|:-|)
          (T
           (LEXICAL-UNREAD-CHAR STREAM)
           'SBST::|:|)))) 
