;;; -*- Mode: Lisp; Package: SLTERMG -*-
(in-package "SLTERM")  ;; creates package for abstract syntax. 

(in-package "SLTERMG")  ;; enters package for generated code.  

(use-package '("ERGOLISP" "OPER" "OCC" "TERM" "SORT" "SB-RUNTIME" "LANG" "NEWATTR"))


(export '( SLTERM-UNPARSE  SLTERM-WIN-UNPARSE ))

(DEFVAR SLTERM-BRACKET-INFO (MAKE-HASH-TABLE :TEST #'EQ)) 
(CLRHASH SLTERM-BRACKET-INFO) 
(MAPC
 #'(LAMBDA (ENTRY)
     (SET-BRACKET-INFO (CAR ENTRY) (CADR ENTRY) (CADDR ENTRY)
                       SLTERM-BRACKET-INFO))
 '((SLTERM:SLTERM SBST::|(| SBST::|)|) (SLTERM:SLTYPE SBST::|(| SBST::|)|))) 

(DEFVAR SLTERM-PREC-INFO (MAKE-HASH-TABLE :TEST #'EQ)) 
(CLRHASH SLTERM-PREC-INFO) 
(MAPC #'(LAMBDA (NT)
          (INIT-PREC-INFO NT SLTERM-PREC-INFO))
      '(SLTERM:SLTERM SLTERM:SLTYPE)) 
(MAPC
 #'(LAMBDA (ENTRY)
     (SET-PREC-INFO (CAR ENTRY) (CADR ENTRY) (CADDR ENTRY) (CADDDR ENTRY)
                    SLTERM-PREC-INFO))
 '((SLTERM:SLTERM SBST::|:| 1 120) (SLTERM:SLTERM SBST::|\\| 1 111)
  (SLTERM:SLTERM JUX 1 100) (SLTERM:SLTERM SBST::|mod| 1 90)
  (SLTERM:SLTERM SBST::|div| 1 90) (SLTERM:SLTERM SBST::* 1 90)
  (SLTERM:SLTERM SBST::- 1 80) (SLTERM:SLTERM SBST::+ 1 80)
  (SLTERM:SLTERM SBST::|::| 1 71) (SLTERM:SLTERM SBST::>= 1 60)
  (SLTERM:SLTERM SBST::=< 1 60) (SLTERM:SLTERM SBST::> 1 60)
  (SLTERM:SLTERM SBST::< 1 60) (SLTERM:SLTERM SBST::|=\\=| 1 50)
  (SLTERM:SLTERM SBST::|=:=| 1 50) (SLTERM:SLTERM SBST::|is| 1 50)
  (SLTERM:SLTERM SBST::= 1 50) (SLTERM:SLTERM SBST::==> 1 41)
  (SLTERM:SLTERM SBST::=> 1 41) (SLTERM:SLTERM SBST::|,| 1 31)
  (SLTERM:SLTERM SBST::|;| 1 21)
  (SLTERM:SLTERM SBST::|hacked\\reverse\\implies| 1 10)
  (SLTERM:SLTERM SBST::|:-| 1 10) (SLTERM:SLTERM SBST::|:| 2 121)
  (SLTERM:SLTERM SBST::|\\| 2 110) (SLTERM:SLTERM JUX 2 101)
  (SLTERM:SLTERM SBST::|mod| 2 91) (SLTERM:SLTERM SBST::|div| 2 91)
  (SLTERM:SLTERM SBST::* 2 91) (SLTERM:SLTERM SBST::- 2 81)
  (SLTERM:SLTERM SBST::+ 2 81) (SLTERM:SLTERM SBST::|::| 2 70)
  (SLTERM:SLTERM SBST::>= 2 61) (SLTERM:SLTERM SBST::=< 2 61)
  (SLTERM:SLTERM SBST::> 2 61) (SLTERM:SLTERM SBST::< 2 61)
  (SLTERM:SLTERM SBST::|=\\=| 2 51) (SLTERM:SLTERM SBST::|=:=| 2 51)
  (SLTERM:SLTERM SBST::|is| 2 51) (SLTERM:SLTERM SBST::= 2 51)
  (SLTERM:SLTERM SBST::==> 2 40) (SLTERM:SLTERM SBST::=> 2 40)
  (SLTERM:SLTERM SBST::|,| 2 30) (SLTERM:SLTERM SBST::|;| 2 20)
  (SLTERM:SLTERM SBST::|hacked\\reverse\\implies| 2 11)
  (SLTERM:SLTERM SBST::|:-| 2 11) (SLTERM:SLTYPE JUX 1 20)
  (SLTERM:SLTYPE SBST::-> 1 11) (SLTERM:SLTYPE JUX 2 21)
  (SLTERM:SLTYPE SBST::-> 2 10))) 

(DEFVAR SLTERM-SPACING-INFO (MAKE-HASH-TABLE :TEST #'EQ)) 
(CLRHASH SLTERM-SPACING-INFO) 
(MAPC
 #'(LAMBDA (T1
            T2
            BP)
     (COND ((ASSOC T2 (GETHASH T1 SLTERM-SPACING-INFO)))
           (T
            (SETF (GETHASH T1 SLTERM-SPACING-INFO)
                  (CONS (LIST T2 BP) (GETHASH T1 SLTERM-SPACING-INFO))))))
 (QUOTE NIL) (QUOTE NIL) (QUOTE NIL)) 

(DEFVAR SLTERM-KEY-TOKEN-MAP (MAKE-HASH-TABLE :TEST #'EQ)) 
(DEFVAR SLTERM-KEY-ESC-TOKEN-MAP (IF SLTERM-ESCAPE-CHAR (MAKE-HASH-TABLE :TEST #'EQ))) 
(DEFVAR SLTERM-LT-TOKEN-MAP (MAKE-HASH-TABLE :TEST #'EQUAL)) 
(DEFVAR SLTERM-LT-ESC-TOKEN-MAP (IF SLTERM-ESCAPE-CHAR (MAKE-HASH-TABLE :TEST #'EQUAL))) 


(DEFUN SLTERMG:SLTERM-UNPARSE (NT AS &KEY (STYLE *UNPARSE-STYLE*))
  (LET* ((*UNPARSER-OP-LIST* SLTERM-ALL-OPERATORS-LIST)
         (*KEY-TOKEN-MAP* SLTERM-KEY-TOKEN-MAP)
         (*KEY-ESC-TOKEN-MAP* SLTERM-KEY-ESC-TOKEN-MAP)
         (*LT-TOKEN-MAP* SLTERM-LT-TOKEN-MAP)
         (*LT-ESC-TOKEN-MAP* SLTERM-LT-ESC-TOKEN-MAP)
         (*APPLY-LT-DIS-FUN* #'APPLY-LEXICAL-TERMINAL-DISCRIMINATOR)
         (*APPLY-LT-DES-FUN* #'APPLY-LEXICAL-TERMINAL-DESTRUCTOR)
         (*APPLY-LT-TOKEN-CONS-FUN* #'APPLY-LT-TOKEN-CONSTRUCTOR)
         (*BRACKET-INFO* SLTERM-BRACKET-INFO)
         (*PREC-INFO* SLTERM-PREC-INFO)
         (SORT (OPSIG-OUTPUT (OPSIG-TABLE-LOOKUP (TERM-OP AS))))
         (NT-NAME
          (COND (NT)
                ((IS-SORT-TTYPE SORT)
                 (DS-SORT-TTYPE SORT))
                (T
                 'SLTERM::SMODULE)))
         (*CASE-SENSITIVE* SLTERM-CASE-SENSITIVE)
         (*ESCAPE-CHARACTER* SLTERM-ESCAPE-CHAR)
         (*RESTRICTED-CHARS* SLTERM-RESTRICTED-CHARS)
         (*STRING-CHAR* SLTERM-STRING-CHAR)
         (*LITERAL-CHAR* SLTERM-LITERAL-CHAR)
         (*KEYWORD-CHAR* SLTERM-KEYWORD-CHAR)
         (*UNPARSE-STYLE*
          (IF (AND STYLE (NOT (CONSP STYLE))) (LIST STYLE) STYLE))
         (*NO-ESCAPES* (OR *NO-ESCAPES* (NULL (INSERT-ESCAPES?))))
         (*CURRENT-PRINT-DEPTH* 1))
    (LET ((UTERM
           (CASE NT-NAME
             (SLTERM::SMODULE (SLTERM-UNP-SMODULE AS :TOP-LEVEL? T))
             (SLTERM::SIMPORT (SLTERM-UNP-SIMPORT AS :TOP-LEVEL? T))
             (SLTERM::STRING-OR-ID (SLTERM-UNP-STRING-OR-ID AS :TOP-LEVEL? T))
             (SLTERM::SMODENTRY (SLTERM-UNP-SMODENTRY AS :TOP-LEVEL? T))
             (SLTERM::SLTERM-DOT (SLTERM-UNP-SLTERM-DOT AS :TOP-LEVEL? T))
             (SLTERM:SLTERM (SLTERM-UNP-SLTERM AS :TOP-LEVEL? T))
             (SLTERM:SLCOBJ (SLTERM-UNP-SLCOBJ AS :TOP-LEVEL? T))
             (SLTERM:SLTYPE (SLTERM-UNP-SLTYPE AS :TOP-LEVEL? T))
             (SLTERM:SLKIND (SLTERM-UNP-SLKIND AS :TOP-LEVEL? T))
             (T (UNPARSE-RUNTIME-ERROR :NT-NOT-UNPARSABLE NT-NAME) NIL))))
      UTERM))) 

(DEFUN SLTERMG:SLTERM-WIN-UNPARSE (UTERM WIDTH &KEY (FONTWIDTH SB-DEFFONTWIDTH) (FONTHEIGHT SB-DEFFONTHEIGHT))
  (LET* ((*CASE-SENSITIVE* SLTERM-CASE-SENSITIVE)
         (*UNPARSER-OP-LIST* SLTERM-ALL-OPERATORS-LIST)
         (*SPACING-INFO* SLTERM-SPACING-INFO))
    (FORMAT-UTERM UTERM WIDTH :FONTWIDTH FONTWIDTH :FONTHEIGHT FONTHEIGHT))) 



(DEFUN SLTERM-UNP-SMODULE (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SMODULE-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SIMPORT (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SIMPORT-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-STRING-OR-ID (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-STRING-OR-ID-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SMODENTRY (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SMODENTRY-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SLTERM-DOT (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SLTERM-DOT-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SLTERM (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SLTERM-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SLCOBJ (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SLCOBJ-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SLTYPE (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SLTYPE-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SLKIND (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'SLTERM-UNP-SLKIND-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN SLTERM-UNP-SMODULE-AUX (AS)
  (LET (V0
        V1
        V2
        V3
        V4
        V5)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5)
    (SETF V0 AS)
    (NT-UNP 'SLTERM::SMODULE AS
            ((UNP-UTERM V0
                        ((UNP-BIND 'SEQ_ V0) (UNP-TERM-CONST 'SLTERM::SMODULE)
                         (UNP-NAME 'STRING-OR-ID V1) (UNP-LIST-CONST)
                         (UNP-NAME 'STAR V2) (UNP-LIST-CONST)
                         (UNP-NAME 'STAR V4)
                         (UNP-SEQ
                          (((UNP-KEYWORD 'SBST::|module|))
                           ((UNP-NT SLTERM-UNP-STRING-OR-ID V1))
                           ((UNP-KEYWORD 'SBST::\.))
                           ((UNP-UTERM V2
                                       ((UNP-REPT V2
                                                  ((UNP-UTERM V3
                                                              ((UNP-NT
                                                                SLTERM-UNP-SIMPORT
                                                                V3))))
                                                  V3
                                                  (MAKE-BP :VALUE 0
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))))))
                           ((UNP-UTERM V4
                                       ((UNP-REPT V4
                                                  ((UNP-UTERM V5
                                                              ((UNP-NT
                                                                SLTERM-UNP-SMODENTRY
                                                                V5))))
                                                  V5
                                                  (MAKE-BP :VALUE 0
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST)))))))
                          ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST)))))))))) 



(DEFUN SLTERM-UNP-SIMPORT-AUX (AS)
  (LET (V0
        V1
        V2)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2)
    (SETF V0 AS)
    (NT-UNP 'SLTERM::SIMPORT AS
            ((UNP-UTERM V0
                        ((UNP-BIND 'SEQ_ V0) (UNP-TERM-CONST 'SLTERM::SIMPORT)
                         (UNP-LIST-CONST) (UNP-NAME (QUOTE NIL) V1)
                         (UNP-SEQ
                          (((UNP-KEYWORD 'SBST::|import|))
                           ((UNP-UTERM V1
                                       ((UNP-REPT V1
                                                  ((UNP-UTERM V2
                                                              ((UNP-BIND
                                                                'NONTERMINAL_
                                                                V2)
                                                               (UNP-NAME
                                                                'STRING-OR-ID
                                                                V2)
                                                               (UNP-NT
                                                                SLTERM-UNP-STRING-OR-ID
                                                                V2))))
                                                  V2
                                                  (MAKE-BP :VALUE 0
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))))))
                           ((UNP-KEYWORD 'SBST::\.)))
                          ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST)))))))))) 



(DEFUN SLTERM-UNP-STRING-OR-ID-AUX (AS)
  (LET (V0
        V1)
    (ERGO-IGNORE-IF-UNUSED V0 V1)
    (SETF V0 AS)
    (NT-UNP 'SLTERM::STRING-OR-ID AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::ISSTRING X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::ISID X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-STRING-OR-ID-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-STRING-OR-ID-AUX-ALT-2 V0 V1)))))))) 



(DEFUN SLTERM-UNP-STRING-OR-ID-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET ()
    (ERGO-IGNORE-IF-UNUSED)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM::ISSTRING)
                (UNP-NAME 'STRING V1) (UNP-LT 'SBST::STRING V1))))) 



(DEFUN SLTERM-UNP-STRING-OR-ID-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET ()
    (ERGO-IGNORE-IF-UNUSED)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM::ISID)
                (UNP-NAME 'ID V1) (UNP-LT 'SBST::ID V1))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX (AS)
  (LET (V0
        V1
        V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
    (SETF V0 AS)
    (NT-UNP 'SLTERM::SMODENTRY AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::MKINDING X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::MTYPING X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::MKEYTYPING X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::MINDEXING X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::MKEYINDEXING X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::MSDFORM X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-SMODENTRY-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-SMODENTRY-AUX-ALT-2 V0 V1))
                       ((SLTERM-UNP-SMODENTRY-AUX-ALT-3 V0 V1))
                       ((SLTERM-UNP-SMODENTRY-AUX-ALT-4 V0 V1))
                       ((SLTERM-UNP-SMODENTRY-AUX-ALT-5 V0 V1))
                       ((SLTERM-UNP-SMODENTRY-AUX-ALT-6 V0 V1)))))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::MKINDING)
                (UNP-NAME 'ID V2) (UNP-NAME 'SLKIND V3)
                (UNP-SEQ
                 (((UNP-KEYWORD 'SBST::|kind|)) ((UNP-LT 'SBST::ID V2))
                  ((UNP-NT SLTERM-UNP-SLKIND V3)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::MTYPING)
                (UNP-NAME 'ID V2) (UNP-NAME 'SLTYPE V3)
                (UNP-SEQ
                 (((UNP-KEYWORD 'SBST::|type|)) ((UNP-LT 'SBST::ID V2))
                  ((UNP-NT SLTERM-UNP-SLTYPE V3)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX-ALT-3 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::MKEYTYPING)
                (UNP-NAME 'KEYWORD V2) (UNP-NAME 'SLTYPE V3)
                (UNP-SEQ
                 (((UNP-KEYWORD 'SBST::|type|)) ((UNP-LT 'SBST::KEYWORD V2))
                  ((UNP-NT SLTERM-UNP-SLTYPE V3)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX-ALT-4 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::MINDEXING)
                (UNP-NAME 'ID V2) (UNP-NAME 'NUMBER V3)
                (UNP-SEQ
                 (((UNP-KEYWORD 'SBST::|index|)) ((UNP-LT 'SBST::ID V2))
                  ((UNP-LT 'SBST::NUMBER V3)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX-ALT-5 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::MKEYINDEXING)
                (UNP-NAME 'KEYWORD V2) (UNP-NAME 'NUMBER V3)
                (UNP-SEQ
                 (((UNP-KEYWORD 'SBST::|index|)) ((UNP-LT 'SBST::KEYWORD V2))
                  ((UNP-LT 'SBST::NUMBER V3)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SMODENTRY-AUX-ALT-6 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::MSDFORM)
                (UNP-NAME 'SLTERM V2)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-DOT-AUX (AS)
  (LET (V0
        V1
        V2)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2)
    (SETF V0 AS)
    (NT-UNP 'SLTERM::SLTERM-DOT AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::SLTERM-DOT X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::END-OF-INPUT X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-SLTERM-DOT-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-SLTERM-DOT-AUX-ALT-2 V0 V1)))))))) 



(DEFUN SLTERM-UNP-SLTERM-DOT-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2)
    (ERGO-IGNORE-IF-UNUSED V2)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM::SLTERM-DOT)
                (UNP-NAME 'SLTERM V2)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::\.)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-DOT-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2)
    (ERGO-IGNORE-IF-UNUSED V2)
    (UNP-UTERM V1
               ((UNP-BIND 'UKEYWORD_ V1) (UNP-TERM-CONST 'SLTERM::END-OF-INPUT)
                (UNP-KEYWORD 'SBST::\.))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX (AS)
  (LET (V0
        V1
        V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
    (SETF V0 AS)
    (NT-UNP 'SLTERM:SLTERM AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR ","
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR ";"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "=>"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "=>"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR ":-"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "==>"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "="
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "is"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "=:="
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "=\\="
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "<"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR ">"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "=<"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR ">="
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "::"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "+"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "-"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "*"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "div"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)
                              (AND (DIS-OP 'SLTERM:APPL (TERM-ARGN X 0))
                                   (AND
                                    (DIS-OP 'SLTERM:CON
                                            (TERM-ARGN (TERM-ARGN X 0) 0))
                                    (AND
                                     (DIS-OP 'SLTERM::CKEYWORD
                                             (TERM-ARGN
                                              (TERM-ARGN (TERM-ARGN X 0) 0) 0))
                                     (MATCH-STR "mod"
                                                (TERM-ARGN
                                                 (TERM-ARGN
                                                  (TERM-ARGN (TERM-ARGN X 0) 0)
                                                  0)
                                                 0)))))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:ELLIDEDSLTERM X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:CON X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:APPL X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:ABST X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:TYPED X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-SLTERM-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-2 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-3 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-4 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-5 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-6 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-7 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-8 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-9 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-10 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-11 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-12 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-13 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-14 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-15 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-16 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-17 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-18 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-19 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-20 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-21 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-22 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-23 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-24 V0 V1))
                       ((SLTERM-UNP-SLTERM-AUX-ALT-25 V0 V1)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|,|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 2000 :UNITED-FLAG NIL :SPACES 1 :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE -1000 :UNITED-FLAG NIL :SPACES 1 :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|;|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 2000 :UNITED-FLAG NIL :SPACES 1 :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE -1000 :UNITED-FLAG NIL :SPACES 1 :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-3 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::=>))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 1000 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE -500 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-4 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V3) (UNP-NAME 'SLTERM V2)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|:-|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 1000 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE -500 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-5 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                  (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                  (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                  (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                  (UNP-SEQ
                   (((UNP-NT SLTERM-UNP-SLTERM V2))
                    ((UNP-KEYWORD 'SBST::|hacked\\reverse\\implies|))
                    ((UNP-NT SLTERM-UNP-SLTERM V3)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                  (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                  (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                  (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                  (UNP-SEQ
                   (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|:-|))
                    ((UNP-NT SLTERM-UNP-SLTERM V3)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-6 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::==>))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 1000 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE -500 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-7 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::=))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-8 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|is|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-9 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|=:=|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-10 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|=\\=|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-11 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::<))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-12 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::>))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-13 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::=<))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-14 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::>=))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-15 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|::|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-16 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::+))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-17 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::-))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-18 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::*))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-19 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|div|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-20 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-TERM-CONST 'SLTERM:APPL) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-TERM-CONST 'SLTERM::CKEYWORD) (UNP-BASE-STR)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|mod|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-21 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'UKEYWORD_ V1)
                  (UNP-TERM-CONST 'SLTERM:ELLIDEDSLTERM)
                  (UNP-KEYWORD 'SBST::|hacked\\ellided\\slterm|))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'UKEYWORD_ V1)
                  (UNP-TERM-CONST 'SLTERM:ELLIDEDSLTERM)
                  (UNP-KEYWORD 'SBST::|#|))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-22 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM:CON)
                (UNP-NAME 'SLCOBJ V1) (UNP-NT SLTERM-UNP-SLCOBJ V1))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-23 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'JUX_ V1) (UNP-TERM-CONST 'SLTERM:APPL)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-JUX ((UNP-NT SLTERM-UNP-SLTERM V2)) 'JUX
                         ((UNP-NT SLTERM-UNP-SLTERM V3))
                         (MAKE-BP :VALUE 500 :UNITED-FLAG NIL :SPACES NIL :CRS
                                  NIL :FORMAT (LIST))
                         (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                  NIL :FORMAT (LIST))
                         (MAKE-BP :VALUE 500 :UNITED-FLAG NIL :SPACES NIL :CRS
                                  NIL :FORMAT (LIST))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-24 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:ABST)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTERM V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|\\|))
                  ((UNP-NT SLTERM-UNP-SLTERM V3)))
                 ((MAKE-BP :VALUE 1000 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 1000 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTERM-AUX-ALT-25 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:TYPED)
                (UNP-NAME 'SLTERM V2) (UNP-NAME 'SLTYPE V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTERM V2)) ((UNP-KEYWORD 'SBST::|:|))
                  ((UNP-NT SLTERM-UNP-SLTYPE V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLCOBJ-AUX (AS)
  (LET (V0
        V1)
    (ERGO-IGNORE-IF-UNUSED V0 V1)
    (SETF V0 AS)
    (NT-UNP 'SLTERM:SLCOBJ AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM::CKEYWORD X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:CNAMED X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:CNUMBER X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:CSTRING X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-SLCOBJ-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-SLCOBJ-AUX-ALT-2 V0 V1))
                       ((SLTERM-UNP-SLCOBJ-AUX-ALT-3 V0 V1))
                       ((SLTERM-UNP-SLCOBJ-AUX-ALT-4 V0 V1)))))))) 



(DEFUN SLTERM-UNP-SLCOBJ-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET ()
    (ERGO-IGNORE-IF-UNUSED)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM::CKEYWORD)
                (UNP-NAME 'KEYWORD V1) (UNP-LT 'SBST::KEYWORD V1))))) 



(DEFUN SLTERM-UNP-SLCOBJ-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET ()
    (ERGO-IGNORE-IF-UNUSED)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM:CNAMED)
                (UNP-NAME 'ID V1) (UNP-LT 'SBST::ID V1))))) 



(DEFUN SLTERM-UNP-SLCOBJ-AUX-ALT-3 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET ()
    (ERGO-IGNORE-IF-UNUSED)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM:CNUMBER)
                (UNP-NAME 'NUMBER V1) (UNP-LT 'SBST::NUMBER V1))))) 



(DEFUN SLTERM-UNP-SLCOBJ-AUX-ALT-4 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET ()
    (ERGO-IGNORE-IF-UNUSED)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM:CSTRING)
                (UNP-NAME 'STRING V1) (UNP-LT 'SBST::STRING V1))))) 



(DEFUN SLTERM-UNP-SLTYPE-AUX (AS)
  (LET (V0
        V1
        V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
    (SETF V0 AS)
    (NT-UNP 'SLTERM:SLTYPE AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:TCON X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:TFUN X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:TAPPL X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:ELLIDEDSLTYPE X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-SLTYPE-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-SLTYPE-AUX-ALT-2 V0 V1))
                       ((SLTERM-UNP-SLTYPE-AUX-ALT-3 V0 V1))
                       ((SLTERM-UNP-SLTYPE-AUX-ALT-4 V0 V1)))))))) 



(DEFUN SLTERM-UNP-SLTYPE-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'NONTERMINAL_ V1) (UNP-TERM-CONST 'SLTERM:TCON)
                (UNP-NAME 'ID V1) (UNP-LT 'SBST::ID V1))))) 



(DEFUN SLTERM-UNP-SLTYPE-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:TFUN)
                (UNP-NAME 'SLTYPE V2) (UNP-NAME 'SLTYPE V3)
                (UNP-SEQ
                 (((UNP-NT SLTERM-UNP-SLTYPE V2)) ((UNP-KEYWORD 'SBST::->))
                  ((UNP-NT SLTERM-UNP-SLTYPE V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-UNP-SLTYPE-AUX-ALT-3 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UNP-UTERM V1
               ((UNP-BIND 'JUX_ V1) (UNP-TERM-CONST 'SLTERM:TAPPL)
                (UNP-NAME 'SLTYPE V2) (UNP-NAME 'SLTYPE V3)
                (UNP-JUX ((UNP-NT SLTERM-UNP-SLTYPE V2)) 'JUX
                         ((UNP-NT SLTERM-UNP-SLTYPE V3))
                         (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                  NIL :FORMAT (LIST))
                         (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                  NIL :FORMAT (LIST))
                         (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                  NIL :FORMAT (LIST))))))) 



(DEFUN SLTERM-UNP-SLTYPE-AUX-ALT-4 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3)
    (ERGO-IGNORE-IF-UNUSED V2 V3)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'UKEYWORD_ V1)
                  (UNP-TERM-CONST 'SLTERM:ELLIDEDSLTYPE)
                  (UNP-KEYWORD 'SBST::|hacked\\ellided\\sltype|))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'UKEYWORD_ V1)
                  (UNP-TERM-CONST 'SLTERM:ELLIDEDSLTYPE)
                  (UNP-KEYWORD 'SBST::|#|))))))) 



(DEFUN SLTERM-UNP-SLKIND-AUX (AS)
  (LET (V0
        V1
        V2)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2)
    (SETF V0 AS)
    (NT-UNP 'SLTERM:SLKIND AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:KTYPE X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'SLTERM:KFUN X)))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((SLTERM-UNP-SLKIND-AUX-ALT-1 V0 V1))
                       ((SLTERM-UNP-SLKIND-AUX-ALT-2 V0 V1)))))))) 



(DEFUN SLTERM-UNP-SLKIND-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2)
    (ERGO-IGNORE-IF-UNUSED V2)
    (UNP-UTERM V1
               ((UNP-BIND 'UKEYWORD_ V1) (UNP-TERM-CONST 'SLTERM:KTYPE)
                (UNP-KEYWORD 'SBST::|type|))))) 



(DEFUN SLTERM-UNP-SLKIND-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2)
    (ERGO-IGNORE-IF-UNUSED V2)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'SLTERM:KFUN)
                (UNP-NAME 'SLKIND V2)
                (UNP-SEQ
                 (((UNP-KEYWORD 'SBST::|type|)) ((UNP-KEYWORD 'SBST::->))
                  ((UNP-NT SLTERM-UNP-SLKIND V2)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN SLTERM-DIS-SMODULE (AS)
  (OR (IS-NT-OPSIG? 'SLTERM::SMODULE AS)
      ((LAMBDA (X)
         (DIS-OP 'SLTERM::SMODULE X)) AS))) 



(DEFUN SLTERM-DIS-SIMPORT (AS)
  (OR (IS-NT-OPSIG? 'SLTERM::SIMPORT AS)
      ((LAMBDA (X)
         (DIS-OP 'SLTERM::SIMPORT X)) AS))) 



(DEFUN SLTERM-DIS-STRING-OR-ID (AS)
  (OR (IS-NT-OPSIG? 'SLTERM::STRING-OR-ID AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM::ISID X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::ISSTRING X)) X)))
       AS))) 



(DEFUN SLTERM-DIS-SMODENTRY (AS)
  (OR (IS-NT-OPSIG? 'SLTERM::SMODENTRY AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM::MSDFORM X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::MKEYINDEXING X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::MINDEXING X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::MKEYTYPING X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::MTYPING X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::MKINDING X)) X)))
       AS))) 



(DEFUN SLTERM-DIS-SLTERM-DOT (AS)
  (OR (IS-NT-OPSIG? 'SLTERM::SLTERM-DOT AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM::END-OF-INPUT X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::SLTERM-DOT X)) X)))
       AS))) 



(DEFUN SLTERM-DIS-SLTERM (AS)
  (OR (IS-NT-OPSIG? 'SLTERM:SLTERM AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM:TYPED X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:ABST X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:APPL X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:CON X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:ELLIDEDSLTERM X)) X)))
       AS))) 



(DEFUN SLTERM-DIS-SLCOBJ (AS)
  (OR (IS-NT-OPSIG? 'SLTERM:SLCOBJ AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM:CSTRING X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:CNUMBER X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:CNAMED X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM::CKEYWORD X)) X)))
       AS))) 



(DEFUN SLTERM-DIS-SLTYPE (AS)
  (OR (IS-NT-OPSIG? 'SLTERM:SLTYPE AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM:ELLIDEDSLTYPE X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:TAPPL X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:TFUN X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:TCON X)) X)))
       AS))) 



(DEFUN SLTERM-DIS-SLKIND (AS)
  (OR (IS-NT-OPSIG? 'SLTERM:SLKIND AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'SLTERM:KFUN X)) X)
             ((LAMBDA (X)
                (DIS-OP 'SLTERM:KTYPE X)) X)))
       AS))) 

