%%% Contains definition of predicates for help.  This is "auto-loaded" if
%%% help is requested (and the right directory is in the search path).

module help.

%%% External predicates (used and declared in eLP system module).

% type	help_topics	o.
doc	help_topics
 "``help_topics'' lists the currently documented predicates and constants
by topic.  For each topic, the first line contains special predicates,
the second defined predicates, and the third declared constants.".

% type	describe_item	A -> o.
doc	describe_item
 "``describe_item X'' writes information that eLP has about X.".

% type	document_in_file  string -> o.
doc	document_in_file
 "``document Outputfile'' writes the available on-line documentation to the
file Outputfile for off-line reference.".

type	is_pred		A.
doc	is_pred
 "``is_pred X'' succeeds if X is (or can be instantiated to) a type A1 -> ...
-> An -> o and hence can serve as a predicate.".

is_pred (X:o).
is_pred (X:(A -> B)) :- pi a:A \ (is_pred (X a)).

% type	listing_item	A -> o.
doc	listing_item
 "``listing_item X'' writes information about X and its definition.".

listing_item X :- describe_item X,
	       %% only show listing if it is a predicate and not special.
	       once (switching (warning type_unify) off (
		       is_pred X,
	               not (sigma Topic \ (special X Topic)))),
	       listing_pred X,
	       fail.
listing_item X.

%%% Auxiliary predicates (used only here).

type    help_category   (A -> elp_topic -> o) -> string -> elp_topic -> o.

help_category Cat Cat_string T :-
  switching (warning no_clauses) off
   (switching (warning no_visible_clauses) off
    (not (sigma Sp \ (Cat Sp T)))), !,
  writesans " [No ", writesans Cat_string, writesans "]".
help_category Cat Cat_string T :- 
  Cat X T, writesans " ", writeered X, fail.
help_category Cat Cat_string T.

%%% The external predicate.

help_topics :- topic T String, nl, writesans String, writesans ": ", nl,
	       tab 5, help_category special "special predicates" T,
		       writesans "; ", nl,
	       tab 5, help_category defined "defined predicates" T,
		       writesans "; ", nl,
	       tab 5, help_category const "declared constants" T,
		       writesans "; ", fail.
help_topics.

%%% Now auxiliary predicates for documentation.

type    plain_describe  A -> o.

plain_describe X :- 
  nl, writeered X, writesans " : ", writetype X,
  nl, write_doc_string X.

type    write_doc_string  A -> o.

write_doc_string X :- doc X String, !, writesans String.
write_doc_string X :- writesans "No documentation available.".

type    write_topic     elp_topic -> o.

write_topic T :- topic T String, writesans String.

type	describe_item_do  A -> o.

describe_item_do X :- special X Topic,
   nl, writeered X, writesans " is a special predicate of topic ",
   write_topic Topic, fail.
describe_item_do X :- defined X Topic,
   nl, writeered X, writesans " is a defined predicate of topic ",
   write_topic Topic, fail.
describe_item_do X :- const X Topic,
   nl, writeered X, writesans " is a declared constant of topic ",
   write_topic Topic, fail.
describe_item_do X :- plain_describe X.

%%% Now the definition of the external predicate.

describe_item X :- switching (warning type_unify) off (describe_item_do X).

%%% For producing hardcopy documentation files.
%%% Auxiliary predicate.

type    describe_category  (A -> elp_topic -> o) -> string -> elp_topic -> o.

describe_category Cat Cat_string T :-
  switching (warning no_clauses) off
   (switching (warning no_visible_clauses) off
     (not (sigma X \ (Cat X T)))), !,
  nl, writesans "No ", writesans Cat_string, writesans ".", nl.
describe_category Cat Cat_string T :-
  nl, writesans Cat_string, writesans ":", nl,
  Cat X T, plain_describe X, nl, fail.
describe_category Cat Cat_string T.

%%% Main predicate.

document_in_file Outputfile :-
   writing Outputfile OS \ (telling OS (
     topic T String, nl, writesans "Topic: ", writesans String,
     describe_category special       "Special Predicates"    T,
     describe_category defined       "Defined Predicates"    T,
     describe_category const         "Declared Constants"    T,
     fail)).
document_in_file Outputfile.
