module lists.

type	memb		A -> list A -> o.
type	member		A -> list A -> o.
type	append		list A -> list A -> list A -> o.
type	join		list A -> list A -> list A -> o.
type    memb_and_rest   A -> list A -> list A -> o.
type    nth_item        int -> A -> list A -> o.
type    nth_and_rest    int -> A -> list A -> list A -> o.

doc	memb
 "``memb X L'' succeeds if X is a member of L.  In contrast to ``member'',
this will succeed as often as X unifies with members of L.".
index	memb	2.

memb X (X :: L).
memb X (Y :: L) :- memb X L.

doc	member
 "``member X L'' succeeds if X is a member of L.  In contrast to ``memb'',
this will succeed only once: for the first unifier of X with a member of L.".
index	member	2.

member X (X :: L) :- !.
member X (Y :: L) :- member X L.


doc	append
 "``append L K M'' succeeds if M is the result of appending K to L.".
index	append	1.

append nil K K.
append (X :: L) K (X :: M) :- append L K M.

doc	join
 "``join L K M'' is similar to append except that members of L that already
appear in K are not appended to form M.  Note that this `check' will do
unification!".
index	join	1.

join nil K K.
join (X :: L) K M :- memb X K, !, join L K M.
join (X :: L) K (X :: M) :- join L K M.

doc	memb_and_rest
 "``memb_and_rest X L M'' succeeds for every occurrence of X in L,
where M is the result of removing that occurrence from L.".

memb_and_rest A (A :: Rest) Rest.
memb_and_rest A (B :: Tail) (B :: Rest) :- memb_and_rest A Tail Rest.

doc	nth_item
 "``nth_item N X L'' succeeds if the Nth item of L is X, where
counting starts at 1.  For N = 0 it behaves like ``memb''.".

nth_item 0 A List :- !, memb A List.
nth_item 1 A (B::Rest) :- !, A = B.
nth_item N A (B::Tail) :- M is (N - 1), nth_item M A Tail.

doc	nth_and_rest
 "``nth_and_rest N X L Rest'' succeeds if the Nth item of L is X, and 
Rest is the rest of L.  Counting starts at 1.  For N = 0, it behaves
like memb_and_rest.".

nth_and_rest 0 A List Rest :- !, memb_and_rest A List Rest.
nth_and_rest 1 A (B::Rest) Rest :- !, A = B.
nth_and_rest N A (B::Tail) (B::Rest) :-
  M is (N - 1), nth_and_rest M A Tail Rest.
