;;; -*- Mode: Lisp; Package: ELP -*-
;;;
;;; Definition of G and D formulas.  Also, clauses and translation of D
;;; formulas to clauses.
;;;
;;; Author: Conal Elliott.  Last Modified Mon Sep 11 06:08:52 1989
;;;
;;; Sccs Id @(#)lp-form.lisp	1.22 9/15/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :ELP) (use-package :ergolisp)

(export '(*unparse-forms-p*))

(defsconstr "

    DATATYPE Gform  =			%    Goal formula
         Gtrue				% Truth
      |  Gand of Gform, Gform		% Conjunction
      |  Gor of Gform, Gform		% Disjunction
      |  Gall of Gform			% Universal
      |  Gexists of Gform		% Existential
      |  Gimplies of Dform, Gform	% Implication
      |	 Gspecial of Special, T	        % Special predicate goal
      |  Gatom of Predicate, Term	% Atomic G formula (note 3)
      |	 Glam of Symbol, Typ, Gform	% Lambda (note 4)
      |  Gflex of Term			% Flexible term (note 2)


    DATATYPE Dform =			%    D formula
         Dand of Dform, Dform		% Conjunction
      |  Dall of Dform			% Universal
      |	 Dimplies of Gform, Dform	% Implication
      |  Datom of Predicate, Term	% Atomic D formula (note 3)
      |	 Dlam of Symbol, Typ, Gform	% Lambda (note 4)
      |	 Dflex of Term			% Flexible term (note 2)

%% Notes:
%% 
%%   2.  Just store the term.  Probably would be more efficient to store
%%       the head and args, but this would widen the interface, so save it
%%       for later.
%%
%%   3.  It would be more efficient to store program entry, rather than the
%%       predicate here.  Then we wouldn't have to do the hashing at run
%%       time.
%%
%%   4.  Used by the quantifier formulas and some specials.
")


;;; This next stuff is to alter the print functions for Gform and Dform
;;; constructors.  I plan to replace it with a more elegant solution, perhaps
;;; "print-filters".

(defvar *unparse-forms-p* t
  "Whether to unparse gforms and dforms on printing.  Defaults to t.")


(defmacro redefine-gform-printers (&rest ops)
  `(progn
     ,@(mapcar
	#'(lambda (op)
	    `(defun ,(intern (concatenate 'string "PRINT-G" (symbol-name op))
			     :ELP)
	       (gform stream depth)
	       (if *unparse-forms-p*
		   (write (tlang-call gform-to-sterm gform () () () depth)
			  :stream stream
			  :pretty nil)
		   (,(intern (concatenate 'string "PRINT-G" (symbol-name op)
					  "-ORIG")
			     :ELP)
		    gform stream depth))))
	ops)))

(redefine-gform-printers true and or all exists implies special
			 atom lam flex)


(defmacro redefine-dform-printers (&rest ops)
  `(progn
     ,@(mapcar
	#'(lambda (op)
	    `(defun ,(intern (concatenate 'string "PRINT-D" (symbol-name op))
			     :ELP)
	       (dform stream depth)
	       (if *unparse-forms-p*
		   (write (tlang-call dform-to-sterm dform () () () depth)
			  :stream stream
			  :pretty nil)
		   (,(intern (concatenate 'string "PRINT-D" (symbol-name op)
					  "-ORIG")
			     :ELP)
		    dform stream depth))))
	ops)))

(redefine-dform-printers and all implies atom lam flex)
