;;; -*- Mode: Lisp; Package: ELP -*-
;;;
;;; Stuff to fix lexed names.  Puts them into the ELP package, and strips
;;; off the special character that overrides their lexical operator status.
;;;
;;; Author: Conal Elliott.  Last Modified Mon Sep 11 06:08:51 1989
;;;
;;; For now, I'm not putting back the special operator character.
;;; 
;;; Sccs Id @(#)lp-id.lisp	1.20 9/15/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :ELP) (use-package :ergolisp)

(export '(lp-id lp-key lp-lit))

(ddefun lp-id ( (intern name-string :ELP) new-package)
  "The same as term:mk-id, but switches from the ELP to given package.
Its destructuring inverse switches back."
  (term:mk-id (intern name-string new-package)))

(ddefun lp-id-name ( (term:mk-id (intern name-string _)) )
  (intern name-string :ELP))

(ddefun lp-id-package ( (term:mk-id (intern _ new-package)) )
  new-package)

(declare-constructor lp-id (lp-id-name lp-id-package))


;;; For destructuring keywords.

(ddefun lp-key ( (intern name-string :ELP) )
  "The same as term:mk-keyword, but switches from the ELP to given package.
Its destructuring inverse switches back.
Forging this to work around SB problem."
  ;; This relies on the fact the the SB does not discriminate on
  ;; type of non-terminals.  Really, this should make a keyword.
  (term:mk-string name-string))

(defun lp-key-name (lex-term)
  (dcase lex-term
    ( (term:mk-keyword name-string ) (intern name-string :ELP) )
    ( (term:mk-string str) (intern str :ELP) )))

(declare-constructor lp-key (lp-key-name))

;;; For literals.

(ddefun lp-lit ( (intern name-string :ELP) new-package)
  "The same as term:mk-lit, but switches from the ELP to given package.
Its destructuring inverse switches back."
  (term:mk-literal (intern name-string new-package)))

(ddefun lp-lit-name ( (term:mk-literal (intern name-string _)) )
  (intern name-string :ELP))

(ddefun lp-lit-package ( (term:mk-literal (intern _ new-package)) )
  new-package)

(declare-constructor lp-lit (lp-lit-name lp-lit-package))

;;; For strings that name constants.  Used in the grammar augments for
;;; infix operators.

(ddefun lp-str ( (intern name-string :ELP) )
  "The same as term:mk-str, but switches from the ELP to given package.
Its destructuring inverse switches back."
  (term:mk-string name-string))

(ddefun lp-str-name ( (term:mk-string name-string ) )
  (intern name-string :ELP))

(declare-constructor lp-str (lp-str-name))
