;;; -*- Mode: Lisp; Package: LTERM -*-
;;;
;;; Types and Terms in context.  Used by the LP term language interface.
;;; Their main value is in their print functions, which convert to the
;;; corresponding syntactic forms.
;;;
;;; Author: Conal Elliott.  Last Modified Tue Oct 24 20:36:08 1989
;;;
;;; Sccs Id @(#)lterm-cterm.lisp	1.22 10/24/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :LTERM) (use-package :ergolisp)

(export '(*unparse-lterms-p*))

(defsconstr "

    DATATYPE Lctype of Symbol*, Ltype

    DATATYPE Lcterm of Symbol*, Symbol*, Ltype*, Lterm
")


(ddefun print-lctype ( (Lctype tvnames ltype) stream depth )
  (write (to-sltype ltype tvnames depth) :stream stream :pretty nil))

(ddefun print-lcterm ( (Lcterm tvnames vnames ltypes lterm) stream depth )
  (write (to-slterm lterm ltypes tvnames vnames depth)
	 :stream stream :pretty nil))

(ddefun mk-lctype (tvnames _ _ ltype)
  "Like Lctype, but also takes vnames and vtypes, since this is what the
LP term language interface expects.  (They will be used in the dependent
calculus.)"
  (Lctype tvnames ltype))


;;; This next stuff is to alter the print functions for Lterm constructors.
;;; I plan to replace it with a more elegant solution, perhaps "print-filters".
;;; Note that, when possible, one should try to print lcterms instead of terms,
;;; but this is still useful for the tracer.

(defvar *unparse-lterms-p* t
  "Whether to unparse lterms and ltypes on printing.  Defaults to t.")

;;; Ought to combine these three macros into one.

(defmacro redefine-lterm-printers (&rest ops)
  `(progn
     ,@(mapcar
	#'(lambda (op)
	    `(defun ,(intern (concatenate 'string "PRINT-" (symbol-name op))
			     :LTERM)
	       (lterm stream depth)
	       (if *unparse-lterms-p*
		   (write (lcterm () () () lterm)
			  :stream stream
			  :pretty nil)
		   (,(intern (concatenate 'string "PRINT-" (symbol-name op)
					  "-ORIG")
			     :LTERM)
		    lterm stream depth))))
	ops)))

(redefine-lterm-printers const bvar evar uvar appl abst)


(defmacro redefine-ltype-printers (&rest ops)
  `(progn
     ,@(mapcar
	#'(lambda (op)
	    `(defun ,(intern (concatenate 'string "PRINT-" (symbol-name op))
			     :LTERM)
	       (ltype stream depth)
	       (if *unparse-lterms-p*
		   (write (lctype () ltype)
			  :stream stream
			  :pretty nil)
		   (,(intern (concatenate 'string "PRINT-" (symbol-name op)
					  "-ORIG")
			     :LTERM)
		    ltype stream depth))))
	ops)))

(redefine-ltype-printers tcon tbvar tevar tfun tappl)

;;; Following function was inserted to fix eLP Bug 0 to Version 0.14.

(defun rename-if-conflict (tvnames so-far)
  (if (null tvnames)
      (reverse so-far)
      (let ((tvsym (first tvnames)))
	(if (member tvsym so-far)
	    (do ((num 1 (1+ num))
		 (trysym tvsym (intern (concatenate 'string (symbol-name tvsym)
						    (format nil "~D" num))
				       (symbol-package tvsym))))
		((not (member trysym so-far))
		 (rename-if-conflict (rest tvnames) (cons trysym so-far))))
	    (rename-if-conflict (rest tvnames) (cons tvsym so-far))))))

(defun print-ltyfam (ltyfam stream depth)
  (if *unparse-lterms-p*
      (dlet ( ((Ltyfam tvnames ltype) ltyfam) )
	(let ((tvnames (rename-if-conflict tvnames nil)))
	  (print-lctype (Lctype tvnames ltype) stream depth)))
      (print-ltyfam-orig ltyfam stream depth)))


(defmacro redefine-lkind-printers (&rest ops)
  `(progn
     ,@(mapcar
	#'(lambda (op)
	    `(defun ,(intern (concatenate 'string "PRINT-" (symbol-name op))
			     :LTERM)
	       (lkind stream depth)
	       (if *unparse-lterms-p*
		   (write (to-slkind lkind)
			  :stream stream
			  :pretty nil)
		   (,(intern (concatenate 'string "PRINT-" (symbol-name op)
					  "-ORIG")
			     :LTERM)
		    lkind stream depth))))
	ops)))

(redefine-lkind-printers ktype kfun)
