;;; -*- Mode: Lisp; Package: LTERM -*-
;;;
;;; Handle translation from Lterms to Exps and Exps to Slterms.
;;;
;;; Author: Conal Elliott.  Last Modified Mon Sep 11 06:09:22 1989
;;;
;;; Sccs Id @(#)lterm-exp.lisp	1.7 9/15/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :LTERM) (use-package :ergolisp)

(defun lterm-to-exp (lterm)
  "Convert LTERM to a Exp, for later evaluation."
  (declare-ftype lterm-to-exp (Lterm) elp:Exp)
  (let ((lterm (chase-evars lterm)))
    ;; First separate into first-order head normal form.
    (dlet ( ((values head args) (to-fohnf lterm)) )
      (dcase head
	((Const lcobj _)
	 (dcase lcobj
	   ((named-lcobj name)
	    ;; Better might be to have a list of packages in which to look up
	    ;; a function definition for NAME.
	    (let ((lisp-name (cdr (assoc name elp:*exp-name-alist*))))
	      (unless lisp-name
		(elp:lp-error "Cannot make ~s into an evaluable expression."
			      lterm))
	      (elp:Ecall name lisp-name
			 (mapcar #'lterm-to-exp args))))
	   ((number-lcobj number)
	    (elp:Ebasic number))))
	;; Non constant heads.  Either rigid or flexible head.
	(Bvar
	 (elp:Eflex lterm))
	(Evar
	 (elp:Eflex lterm))
	(Uvar
	 (elp:lp-error "Cannot make an evaluable expression out of uvar ~s."
		       lterm))))))



(defun exp-to-slterm (exp vtypes tvnames vnames depth)
  "Convert EXP to a slterm."
  (declare-ftype exp-to-slterm
    (elp:Exp (List-of Ltype) (List-of Symbol) (List-of Symbol)) slterm:Slterm)
  (if (= depth *elp-print-depth*)
      (slterm:EllidedSlterm)
      (dcase exp
	((elp:Ebasic obj)
	 (typecase obj
	   (Number (slterm:Con (slterm:Cnumber obj)))
	   (t (elp:lp-error "Cannot make basic value ~s into a term." obj))))
	((elp:Ecall name _ args)
	 (add-sappls (slterm:Con (slterm:Cnamed name)) 
		     (mapcar #'(lambda (arg)
				 (exp-to-slterm arg vtypes tvnames vnames
						(1+ depth)))
			     args)))
	((elp:Eflex lterm)
	 (to-slterm lterm vtypes tvnames vnames depth)))))


(defun value-lterm (value)
  "Convert VALUE to an Lterm if possible.  Handles Lisp numbers, strings,
constants, and conses."
  (typecase value
    (Number (Const (Number-lcobj value) *number-ltype*))    
    (t (elp:lp-error "Cannot make basic value ~s into a term." value))))
; Compiling SWITCH-VARIABLE-VALUE
