;;; -*- Mode: Lisp; Package: ELP -*-
;;;
;;; Lterm-dependent special predicate support
;;;
;;; Author: Conal Elliott.  Last Modified Mon Sep 11 06:08:54 1989
;;;
;;;  Maybe this should be in the LTERM package.
;;; Sccs Id @(#)lterm-special.lisp	1.12 9/15/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :ELP) (use-package :ergolisp)

(defswitch printtypes lterm:*to-slterm-with-types-p*
  "If ON, print types in terms.")

(defswitch projfirst lterm:*proj-first*
  "If ON, the unifier will try projections first.")

(defswitch normalize lterm:*to-slterm-normalize-p*
  "If OFF, do not normalize when printing terms.")

(defswitch bounded_unify lterm::*bounded-unify*
  "If ON, unification will proceed only to the depth specified by *depth-bound*.")

(defswitch (warning . typevar) lterm::*warn-typevar*
  "If OFF, do not print a warning when a range type of an argument to
match is a variable.  The interpreter may be incomplete in such a situation.")

(defswitch (warning . type_unify) lterm::*warn-type-unify*
  "If OFF, do not print a warning when two constants that are to be unified
have different type.")

(defswitch (warning . too_deep) lterm::*warn-too-deep*
  "If OFF, do not print a warning when the depth bound is exceeded during
unification.")

(defswitch (tracing . match) lterm::*trace-match*
  "If ON, print messages when MATCH is entered and when it selects
a substitution term.  MATCH is the only place where unification can branch.
Tabbing of MATCH is separate from tabbing in the tracing of goals or
clauses.")

#|
(defun write-lterm (lterm)
  "Unparse an lterm to *elp-standard-output*."
  (sbrt:unparse-term (lterm:to-slterm lterm () ())
		     :nt 'slterm::slterm
		     :stream *elp-standard-output*))
|#

(defspecial depth_bounding (rterm rgform) nil
  ( (list number-term gform) con ctag sc )
  "``depth_bounding S G'' sets the input prompt to S while solving G."
  (let ((old-bound lterm::*depth-bound*)
	(lterm::*depth-bound* (term-number-value number-term)))
    (solve gform con ctag
	   (switch-variable-value 'lterm::*depth-bound*
				  lterm::*depth-bound* old-bound sc))))

(defdefault depth_bounding (number)
  (when (not (integerp number))
    (lp-error "~A is not a true integer." number))
  (setq lterm::*depth-bound* number))

(defspecial printing_depth (rterm rgform) nil
  ( (list number-term gform) con ctag sc )
  "``printing_depth N G'' sets the printing depth to N while solving G."
  (let ((old-bound lterm:*elp-print-depth*)
	(lterm:*elp-print-depth* (term-number-value number-term)))
    (solve gform con ctag
	   (switch-variable-value 'lterm:*elp-print-depth*
				  lterm:*elp-print-depth* old-bound sc))))

(defdefault printing_depth (number)
  (when (not (integerp number))
    (lp-error "~A is not a true integer." number))
  (setq lterm:*elp-print-depth* number))
