;;; -*- Mode: Lisp; Package: LTERM -*-
;;;
;;; Support for translating lterms to specialized representations.
;;;
;;; Author: Conal Elliott.  Last Modified Mon Sep 11 06:09:00 1989
;;;
;;; Sccs Id @(#)lterm-translator.lisp	1.5 9/15/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :LTERM) (use-package :ergolisp)

(deftype Lterm-translator-fun ()
  "Type of specialized lterm translator functions.  Takes an lterm, a list of
bound term variable names, and a list of bound type variable names, and 
produces the specialized representation."
  `(Function-of (Lterm (List-of Ltype) (List-of Symbol) (List-of Symbol)) T))

(defvar *lterm-translator-table*
  (make-hash-table :test #'eq :size 10)
  "The lterm translator table.")


(defun lterm-translator (symbol)
  "Look up the translator function for the given SYMBOL."
  (declare-ftype lterm-translator (Symbol) Lterm-translator-fun)
  (values (gethash symbol *lterm-translator-table*)))

(defsetf lterm-translator (symbol) (fun)
  `(setf (gethash ,symbol *lterm-translator-table*) ,fun))


(defun target-main-op (ltype)
  "Given an LTYPE, skip past function type domains to the range, and from
there, if we have a tcon applied to zero or more arguments, return the op.
Otherwise, return nil."
  (declare-ftype target-main-op (Ltype) (Optional Symbol))
  (dlet ( ((values _ range) (strip-domains ltype)) )
    (and (or (is-Tcon range)
	     (is-Tappl range))
	 (grab-tappl-rator range))))

(defun grab-tappl-rator (ltype)
  "Strip away tappl rands, returning the tcon name."
  (declare-ftype grab-tappl-rator (Ltype) (Optional Symbol))
  (let ((ltype (chase-tevars ltype)))
    (dcase ltype
      ((Tcon name _) name)
      ((Tappl rator _)
       (grab-tappl-rator rator)))))
