;;; -*- Mode: Lisp; Package: LTERM -*-
;;;
;;; Concrete syntax support for slterms
;;;
;;; Author: Conal Elliott.  Last Modified Mon Sep 11 06:09:31 1989
;;;
;;; Sccs Id @(#)slterm-io.lisp	1.13 9/15/89
;;; ******************************************************************* ;;;
;;;         (c) Copyright 1989 by Carnegie Mellon University.           ;;;
;;;                        All rights reserved.                         ;;;
;;;         This code was written as part of the Ergo project.          ;;;
;;;  If you want to use this code or any Ergo software, please contact  ;;;
;;;			Frank Pfenning (fp@cs.cmu.edu)			;;;
;;; ******************************************************************* ;;;


(in-package :LTERM) (use-package :ergolisp)

(export '(parse-slterm parse-smodule unparse-slterm))

(export '(*plain-slterm-lang-dir* load-slterm-lang gen-slterm-lang))

(defun parse-something (nonterminal stream)
  "Parse according to NONTERMINAL from the given STREAM.
Calls elp:lp-error if there is an error in parsing.  Throws 'elp::end-of-file
on end of file (used by the reread special predicate)."
  (declare-ftype parse-something (Symbol Stream) T)
  (dlet ( ((values slterm errorp _ error-string error-args)
	   (sltermg:slterm-parse :nt nonterminal
				 :stream stream
				 :return-errors t)) )
    ;;; Next line is a heuristic for end-of-file recognition.
    (when (eq :eof slterm)
      (throw 'elp::end-of-file
	     (values nil "Unexpected explicit end of file '.'" ())))
    (if errorp
	(if (eq (first error-args) :eof)
	    (throw 'elp::end-of-file
		   (values nil error-string error-args))
	    (apply #'elp:lp-error error-string error-args))
	slterm)))


(defun parse-slterm (stream)
  "Parse a period-terminated slterm from the given STREAM.  See parse-something
for details."
  (declare-ftype parse-slterm (Stream) Slterm)
  (parse-something 'slterm::slterm-dot stream))

(defun parse-smodule (stream)
  "Parse a smodule from the given STREAM.  See parse-something for details."
  ;; Catch an end-of-file here.
  (declare-ftype parse-slterm (Stream) elp::Smodule)
  (dlet ( ((values opt-smodule error-string error-args)
	   (catch 'elp::end-of-file
	     (parse-something 'slterm::smodule stream))) )
    (unless opt-smodule
      (apply #'elp:lp-error error-string error-args))
    ;; Now make sure we are at the end of the stream
    #-allegro 
    (unless (eq (peek-char t stream nil 'end-of-module) 'end-of-module)
      (elp:lp-error "Error in module before ~s" (read-line stream)))
    opt-smodule))

(defun unparse-something (thing nonterminal stream)
  "Unparse THING according to NONTERMINAL to the given STREAM."
  (declare-ftype unparse-something (T Symbol Stream) T)
  (sbrt:unparse-term thing
		     :stream stream
		     :nt nonterminal))

(defun unparse-slterm (slterm stream)
  "Unparse SLTERM to the given STREAM."
  (declare-ftype unparse-slterm (Slterm Stream) )
  (unparse-something slterm 'slterm::slterm stream))
  
